@@ -51,7 +51,7 @@ package com.openexchange.usm.api.cache;
 
 import java.io.Serializable;
 import java.util.Set;
-import com.openexchange.usm.api.session.CompleteSessionID;
+import com.openexchange.usm.api.session.assets.CompleteSessionID;
 
 /**
  * {@link SyncStateCache}: A cache for the sync states stored by a single USM session. A SyncStateCacheProvider may return the same
