@@ -375,6 +375,24 @@ public class ConfigurationProperties {
     public static final String JSON_SERVLET_TIMEFILTER_LIMIT_FUTURE_PROPERTY = "com.openexchange.usm.json.sync.timefilter_limit_future";
 
     public static final int JSON_SERVLET_TIMEFILTER_LIMIT_FUTURE_DEFAULT = 730; // 2 * 365
+    
+    
+    /**
+     * Defines the lower time filter limit in days. Appointments which are in the past beyond this limit will not be synchronised
+     * from/to the client. Overwrites global appointment & mail time filter. 
+     */
+    public static final String JSON_SERVLET_TIMEFILTER_CALENDAR_LIMIT_PAST_PROPERTY = "com.openexchange.usm.json.sync.calendar.timefilter_limit_past";
+
+    public static final int JSON_SERVLET_TIMEFILTER_CALENDAR_LIMIT_PAST_DEFAULT = 365;
+
+    /**
+     * Defines the upper time filter limit in days. Appointments which are in the future beyond this limit will not be
+     * synchronised from/to the client. Overwrites global appointment & mail time filter. 
+     */
+    public static final String JSON_SERVLET_TIMEFILTER_CALENDAR_LIMIT_FUTURE_PROPERTY = "com.openexchange.usm.json.sync.calendar.timefilter_limit_future";
+
+    public static final int JSON_SERVLET_TIMEFILTER_CALENDAR_LIMIT_FUTURE_DEFAULT = 730; // 2 * 365
+    
 
     public static final String JSON_SERVLET_ACCESS_CHECK_TEST_INTERVAL_PROPERTY = "com.openexchange.usm.json.access_check.test_interval";
 
