@@ -60,13 +60,19 @@ import com.openexchange.usm.api.session.Session;
  *
  */
 public class NumberNotNullDataType extends AbstractDataType<Number> {
-	public static final String NAME = "NumberNotNull";
+	
 
-	public void addToJSONArray(Session session, JSONArray parent, Object object) throws JSONException {
-		parent.put((Number) object);
+    public NumberNotNullDataType() {
+        super("NumberNotNull");
+    }
+
+	@Override
+    public void addToJSONArray(Session session, JSONArray parent, Object object) {
+		parent.put(object);
 	}
 
-	public Number checkValue(Object o) {
+	@Override
+    public Number checkValue(Object o) {
 		if (o == null)
 			return 0;
 		if (!(o instanceof Number))
@@ -74,24 +80,23 @@ public class NumberNotNullDataType extends AbstractDataType<Number> {
 		return (Number) o;
 	}
 
-	public Number extractFromJSONArray(Session session, JSONArray array, int index) throws JSONException {
+	@Override
+    public Number extractFromJSONArray(Session session, JSONArray array, int index) throws JSONException {
 		if (array.isNull(index))
 			return 0;
 		return convertToNumber(array.get(index));
 	}
 
-	public Number extractFromJSONObject(Session session, JSONObject jsonObject, String field) throws JSONException {
+	@Override
+    public Number extractFromJSONObject(Session session, JSONObject jsonObject, String field) throws JSONException {
 		if (jsonObject.isNull(field))
 			return 0;
 		return convertToNumber(jsonObject.get(field));
 	}
 
-	public String getName() {
-		return NAME;
-	}
-
-	public void storeInJSONObject(Session session, JSONObject parent, String field, Object object) throws JSONException {
-		parent.put(field, (Number) object);
+	@Override
+    public void storeInJSONObject(Session session, JSONObject parent, String field, Object object) throws JSONException {
+		parent.put(field, object);
 	}
 
 	@Override
