@@ -60,31 +60,35 @@ import com.openexchange.usm.api.session.Session;
  *
  */
 public class TimestampDataType extends AbstractDataType<Long> {
-	public static final String NAME = "Timestamp";
-
-	public void addToJSONArray(Session session, JSONArray parent, Object value) throws JSONException {
-		parent.put((Long) value);
+	
+    public TimestampDataType() {
+	    super("Timestamp");
 	}
 
-	public Long checkValue(Object o) {
+	@Override
+    public void addToJSONArray(Session session, JSONArray parent, Object value) {
+		parent.put(value);
+	}
+
+	@Override
+    public Long checkValue(Object o) {
 		if (o != null && !(o instanceof Long))
 			generateTypeError(o);
 		return (Long) o;
 	}
 
-	public Long extractFromJSONArray(Session session, JSONArray array, int index) throws JSONException {
+	@Override
+    public Long extractFromJSONArray(Session session, JSONArray array, int index) throws JSONException {
 		return array.isNull(index) ? null : array.getLong(index);
 	}
 
-	public Long extractFromJSONObject(Session session, JSONObject jsonObject, String field) throws JSONException {
+	@Override
+    public Long extractFromJSONObject(Session session, JSONObject jsonObject, String field) throws JSONException {
 		return jsonObject.isNull(field) ? null : jsonObject.getLong(field);
 	}
 
-	public String getName() {
-		return NAME;
-	}
-
-	public void storeInJSONObject(Session session, JSONObject parent, String field, Object value) throws JSONException {
+	@Override
+    public void storeInJSONObject(Session session, JSONObject parent, String field, Object value) throws JSONException {
 		parent.put(field, (value == null) ? JSONObject.NULL : (Long) value);
 	}
 }
