@@ -50,8 +50,9 @@ package com.openexchange.usm.cache.ox_adapter;
 
 import java.io.Serializable;
 import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import com.openexchange.exception.OXException;
-import com.openexchange.usm.cache.Cache;
+import com.openexchange.usm.api.cache.Cache;
 
 /**
  * Adapter for the Cache interface to the OX Caching Interface.
@@ -63,20 +64,26 @@ import com.openexchange.usm.cache.Cache;
  */
 public class CacheAdapter<K extends Serializable, V extends Serializable> implements Cache<K, V> {
 
+    private static final Log _journal = LogFactory.getLog(CacheAdapter.class);
+    
 	private final com.openexchange.caching.Cache _cacheImpl;
-	private final Log _journal;
-
-	public CacheAdapter(com.openexchange.caching.Cache cacheImpl, Log log) {
+	
+	/**
+	 * Initializes a new {@link CacheAdapter}.
+	 * @param cacheImpl
+	 */
+	public CacheAdapter(com.openexchange.caching.Cache cacheImpl) {
 		_cacheImpl = cacheImpl;
-		_journal = log;
 	}
 
-	@SuppressWarnings("unchecked")
+	@Override
+    @SuppressWarnings("unchecked")
 	public V get(K name) {
 		return (V) _cacheImpl.get(name);
 	}
 
-	public void put(K name, V obj, boolean invalidate) {
+	@Override
+    public void put(K name, V obj, boolean invalidate) {
 		try {
 			_cacheImpl.put(name, obj, invalidate);
 		} catch (OXException e) {
@@ -84,7 +91,8 @@ public class CacheAdapter<K extends Serializable, V extends Serializable> implem
 		}
 	}
 
-	public void putSafe(K name, V obj) {
+	@Override
+    public void putSafe(K name, V obj) {
 		try {
 			_cacheImpl.putSafe(name, obj);
 		} catch (OXException e) {
@@ -92,7 +100,8 @@ public class CacheAdapter<K extends Serializable, V extends Serializable> implem
 		}
 	}
 
-	public void remove(K name) {
+	@Override
+    public void remove(K name) {
 		try {
 			_cacheImpl.remove(name);
 		} catch (OXException e) {
@@ -100,7 +109,8 @@ public class CacheAdapter<K extends Serializable, V extends Serializable> implem
 		}
 	}
 
-	public void dispose() {
+	@Override
+    public void dispose() {
 		_cacheImpl.dispose();
 	}
 }
