@@ -54,10 +54,11 @@ import java.util.Map;
 import java.util.Properties;
 import java.util.WeakHashMap;
 import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import com.openexchange.caching.CacheService;
 import com.openexchange.exception.OXException;
-import com.openexchange.usm.cache.Cache;
-import com.openexchange.usm.cache.CacheManager;
+import com.openexchange.usm.api.cache.Cache;
+import com.openexchange.usm.api.cache.CacheManager;
 
 /**
  * Cache Manager Adaptor. Uses the OX Caching service.
@@ -65,53 +66,59 @@ import com.openexchange.usm.cache.CacheManager;
  *
  */
 public class CacheManagerAdapter implements CacheManager {
+    
+    private static final Log LOG = LogFactory.getLog(CacheManagerAdapter.class);
 
 	// Keep track of Caches in use for profiling / debugging purposes
-	private final Map<Cache<?, ?>, String> _cacheMap = Collections
-			.synchronizedMap(new WeakHashMap<Cache<?, ?>, String>());
+	private final Map<Cache<?, ?>, String> _cacheMap = Collections.synchronizedMap(new WeakHashMap<Cache<?, ?>, String>());
 
 	private CacheService _cacheService;
 
-	private Log _journal;
-
-	public void activate(Log log, CacheService cacheService) {
-		_journal = log;
+	/**
+	 * Initializes a new {@link CacheManagerAdapter}.
+	 * @param cacheService
+	 */
+	public CacheManagerAdapter(CacheService cacheService) {
 		_cacheService = cacheService;
-		_journal.info("USM->OX CacheManagerAdapter activated");
+		LOG.info("USM->OX CacheManagerAdapter activated");
 	}
 
+	/**
+	 * Deactivate
+	 */
 	public void deactivate() {
 		for (String cacheId : _cacheMap.values()) {
 			try {
 				_cacheService.freeCache(cacheId);
 			} catch (OXException e) {
-				_journal.error("Can not free cache: " + cacheId, e);
+				LOG.error("Can not free cache: " + cacheId, e);
 			}
 		}
 		_cacheMap.clear();
-		_journal.info("USM->OX CacheManagerAdapter deactivated");
-		_journal = null;
+		LOG.info("USM->OX CacheManagerAdapter deactivated");
 	}
 
-	public <K extends Serializable, V extends Serializable> Cache<K, V> createCache(String id, Class<K> keyClass,
+	@Override
+    public <K extends Serializable, V extends Serializable> Cache<K, V> createCache(String id, Class<K> keyClass,
 			Class<V> valueClass) {
 		return createCache(id, keyClass, valueClass, null);
 	}
 
-	public <K extends Serializable, V extends Serializable> Cache<K, V> createCache(String id, Class<K> keyClass,
+	@Override
+    public <K extends Serializable, V extends Serializable> Cache<K, V> createCache(String id, Class<K> keyClass,
 			Class<V> valueClass, Properties properties) {
 		com.openexchange.caching.Cache cacheImpl;
 		try {
 		    _cacheService.loadConfiguration(properties);
 			cacheImpl = _cacheService.getCache(id);
 		} catch (OXException e) {
-			_journal.error("Can not create cache: " + id, e);
+			LOG.error("Can not create cache: " + id, e);
 			return null; //TODO: maybe throw exception
 		}
-		CacheAdapter<K, V> cache = new CacheAdapter<K, V>(cacheImpl, _journal);
+		CacheAdapter<K, V> cache = new CacheAdapter<K, V>(cacheImpl);
 		_cacheMap.put(cache, id);
-		if (_journal.isDebugEnabled())
-			_journal.debug("Created Cache " + id + ", " + _cacheMap.size() + " Caches active");
+		if (LOG.isDebugEnabled())
+			LOG.debug("Created Cache " + id + ", " + _cacheMap.size() + " Caches active");
 		return cache;
 	}
 }
