@@ -55,10 +55,12 @@ import static com.openexchange.usm.api.datatypes.DataTypes.NUMBER_NOT_NULL;
 import static com.openexchange.usm.api.datatypes.DataTypes.STRING;
 import static com.openexchange.usm.api.datatypes.DataTypes.TIME;
 import java.util.BitSet;
-import com.openexchange.usm.api.contenttypes.AppointmentContentType;
-import com.openexchange.usm.api.contenttypes.ContentTypeField;
-import com.openexchange.usm.api.contenttypes.ContentTypeTransferHandler;
-import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
+import com.openexchange.usm.api.contenttypes.calendar.AppointmentContentType;
+import com.openexchange.usm.api.contenttypes.calendar.CalendarConstants;
+import com.openexchange.usm.api.contenttypes.common.CommonConstants;
+import com.openexchange.usm.api.contenttypes.common.ContentTypeField;
+import com.openexchange.usm.api.contenttypes.common.DefaultContentTypes;
+import com.openexchange.usm.api.contenttypes.transferhandlers.ContentTypeTransferHandler;
 import com.openexchange.usm.api.datatypes.PIMAttachmentsDataType;
 import com.openexchange.usm.api.exceptions.AuthenticationFailedException;
 import com.openexchange.usm.api.exceptions.OXCommunicationException;
@@ -66,7 +68,6 @@ import com.openexchange.usm.api.exceptions.USMException;
 import com.openexchange.usm.api.session.DataObject;
 import com.openexchange.usm.api.session.Session;
 import com.openexchange.usm.contenttypes.util.AbstractContentType;
-import com.openexchange.usm.contenttypes.util.UtilConstants;
 import com.openexchange.usm.datatypes.tasks.calendar.CommonCalendarTasksFieldNames;
 import com.openexchange.usm.datatypes.tasks.calendar.ConfirmingParticipantDataType;
 import com.openexchange.usm.datatypes.tasks.calendar.ParticipantIdentifierDataType;
@@ -76,15 +77,15 @@ public class AppointmentContentTypeImpl extends AbstractContentType implements A
 
 	private final static ContentTypeField[] FIELDS = {
 			//Common object data
-			new ContentTypeField(1, UtilConstants.FIELD_ID, STRING, false, true, false, false), //Object ID
-			new ContentTypeField(20, UtilConstants.FOLDER_ID, STRING, false, false, true, false), //Object ID of the parent folder.
-			new ContentTypeField(2, UtilConstants.CREATED_BY, STRING), //User ID of the user who created this object.
-			new ContentTypeField(3, UtilConstants.MODIFIED_BY, STRING), //User ID of the user who last modified this object.
-			new ContentTypeField(4, UtilConstants.CREATION_DATE, TIME), //Date and time of creation.
-			new ContentTypeField(5, UtilConstants.LAST_MODIFIED, TIME), //Date and time of the last modification.
-			new ContentTypeField(100, UtilConstants.CATEGORIES, STRING), //Each element is a string, naming a category. Order is preserved. Changing the order counts as modification of the object.
-			new ContentTypeField(101, UtilConstants.PRIVATE_FLAG, BOOLEAN), //Overrides folder permissions in shared private folders: When true, this object is not visible to anyone except the owner.
-			new ContentTypeField(104, UtilConstants.NUMBER_OF_ATTACHMENTS, NUMBER), //Number of attachments
+			new ContentTypeField(1, CommonConstants.FIELD_ID, STRING, false, true, false, false), //Object ID
+			new ContentTypeField(20, CommonConstants.FOLDER_ID, STRING, false, false, true, false), //Object ID of the parent folder.
+			new ContentTypeField(2, CommonConstants.CREATED_BY, STRING), //User ID of the user who created this object.
+			new ContentTypeField(3, CommonConstants.MODIFIED_BY, STRING), //User ID of the user who last modified this object.
+			new ContentTypeField(4, CommonConstants.CREATION_DATE, TIME), //Date and time of creation.
+			new ContentTypeField(5, CommonConstants.LAST_MODIFIED, TIME), //Date and time of the last modification.
+			new ContentTypeField(100, CommonConstants.CATEGORIES, STRING), //Each element is a string, naming a category. Order is preserved. Changing the order counts as modification of the object.
+			new ContentTypeField(101, CommonConstants.PRIVATE_FLAG, BOOLEAN), //Overrides folder permissions in shared private folders: When true, this object is not visible to anyone except the owner.
+			new ContentTypeField(104, CommonConstants.NUMBER_OF_ATTACHMENTS, NUMBER), //Number of attachments
 			//Detailed task and appointment data
 			new ContentTypeField(200, CommonCalendarTasksFieldNames.TITLE, STRING), //Short description.
 			new ContentTypeField(201, CommonCalendarTasksFieldNames.START_DATE, TIME), //Inclusive start of the event as Date for tasks and whole day appointments and Time for normal appointments
@@ -115,7 +116,7 @@ public class AppointmentContentTypeImpl extends AbstractContentType implements A
 			new ContentTypeField(401, CalendarConstants.FULL_TIME, BOOLEAN, false, false, false, true), // True if the appointment is a whole day appointment, false otherwise.
 			new ContentTypeField(402, CalendarConstants.SHOWN_AS, NUMBER), //Describes, how this appointment appears in availability queries: 1 reserved 2 temporary 3 absent 4 free
 			new ContentTypeField(102, CalendarConstants.COLOR_LABEL, NUMBER), //Color number used by Outlook to label the appointment. The assignment of colors to numbers is arbitrary and specified by the client. The numbers are integer numbers
-			new ContentTypeField(105, UtilConstants.ATTACHMENTS_LAST_MODIFIED, new PIMAttachmentsDataType()), // New complex field that contains attachments_last_modified for updates and additionally an array PIMAttachment for persistent storing in the SyncState
+			new ContentTypeField(105, CommonConstants.ATTACHMENTS_LAST_MODIFIED, new PIMAttachmentsDataType()), // New complex field that contains attachments_last_modified for updates and additionally an array PIMAttachment for persistent storing in the SyncState
 			new ContentTypeField(223, CommonCalendarTasksFieldNames.UID, STRING), //the UID of the appointment
 			new ContentTypeField(224, CalendarConstants.ORGANIZER, STRING), //the Organizer of the appointment
 			new ContentTypeField(225, CalendarConstants.SEQUENCE, NUMBER), //iCal sequence number.
@@ -128,21 +129,18 @@ public class AppointmentContentTypeImpl extends AbstractContentType implements A
 
 	private AppointmentContentTypeTransferHandler _transferHandler;
 
-	/**
-	 * Constructor is package private to discourage access from outside the bundle (but to allow usage in test cases)
-	 */
-	AppointmentContentTypeImpl() {
-	}
-
-	public ContentTypeField[] getFields() {
+	@Override
+    public ContentTypeField[] getFields() {
 		return FIELDS;
 	}
 
-	public String getID() {
+	@Override
+    public String getID() {
 		return DefaultContentTypes.CALENDAR_ID;
 	}
 
-	public ContentTypeTransferHandler getTransferHandler() {
+	@Override
+    public ContentTypeTransferHandler getTransferHandler() {
 		return _transferHandler;
 	}
 
@@ -166,33 +164,40 @@ public class AppointmentContentTypeImpl extends AbstractContentType implements A
 		return true;
 	}
 
-	public void confirm(DataObject object, int response) throws AuthenticationFailedException, OXCommunicationException {
+	@Override
+    public void confirm(DataObject object, int response) throws AuthenticationFailedException, OXCommunicationException {
 		_transferHandler.confirm(object, response);
 	}
 
-	public void confirm(DataObject object, int response, String confirmMessage) throws AuthenticationFailedException,
+	@Override
+    public void confirm(DataObject object, int response, String confirmMessage) throws AuthenticationFailedException,
 			OXCommunicationException {
 		_transferHandler.confirm(object, response, confirmMessage);
 	}
 
-	public DataObject[] getAllAppointments(Session session, BitSet requestedFields) throws USMException {
+	@Override
+    public DataObject[] getAllAppointments(Session session, BitSet requestedFields) throws USMException {
 		return _transferHandler.getAllAppointments(session, requestedFields);
 	}
 
-	public DataObject[] getAllRecurrencesAsAppointments(Session session, BitSet requestedFields, DataObject seriesObject)
+	@Override
+    public DataObject[] getAllRecurrencesAsAppointments(Session session, BitSet requestedFields, DataObject seriesObject)
 			throws USMException {
 		return _transferHandler.getAllRecurrencesAsAppointments(session, requestedFields, seriesObject);
 	}
 
-	public int getCode() {
+	@Override
+    public int getCode() {
 		return DefaultContentTypes.CALENDAR_CODE;
 	}
 
-	public boolean supportsPIMAttachments() {
+	@Override
+    public boolean supportsPIMAttachments() {
 		return true;
 	}
 
-	public Object getObjectGroupOwner(DataObject object) {
+	@Override
+    public Object getObjectGroupOwner(DataObject object) {
 		Object recurrence_id = object.getFieldContent(CalendarConstants.RECURRENCE_ID);
 		if (recurrence_id == null || ((Number) recurrence_id).intValue() == 0)
 			return object.getID();
@@ -200,15 +205,18 @@ public class AppointmentContentTypeImpl extends AbstractContentType implements A
 			return String.valueOf(recurrence_id);
 	}
 
-	public String resolveUID(Session session, String uid) throws USMException {
+	@Override
+    public String resolveUID(Session session, String uid) throws USMException {
 		return _transferHandler.resolveUID(session, uid);
 	}
 
-	public void confirm(DataObject object, int response, String confirmMessage, String participantId)
+	@Override
+    public void confirm(DataObject object, int response, String confirmMessage, String participantId)
 			throws AuthenticationFailedException, OXCommunicationException {
 		_transferHandler.confirm(object, response, confirmMessage, participantId);
 	}
 
+    @Override
     public DataObject[] getAllChangeExceptions(Session session, BitSet requestedFields, DataObject seriesObject) throws USMException {
         return _transferHandler.getAllChangeExceptions(session, requestedFields, seriesObject);
     }
