@@ -147,8 +147,7 @@ public class AppointmentContentTypeTransferHandler extends AbstractTransferHandl
         parameters.put(CommonConstants.COLUMNS, createColumnsParameter(requestedFields));
         parameters.put(CommonConstants.RECURRENCE_MASTER, Boolean.TRUE.toString());
         Session session = folder.getSession();
-        parameters.put(CommonConstants.START, String.valueOf(session.getStartDate()));
-        parameters.put(CommonConstants.END, String.valueOf(session.getEndDate()));
+        addTimeLimitParameters(parameters, session);
         addObjectsLimitParameters(folder.getSession(), parameters);
         addShowPrivateParameter(parameters, session);
         DataObject[] result = performActionAndCheckRights(CommonConstants.ACTION_ALL, folder, requestedFields, parameters);
@@ -156,6 +155,12 @@ public class AppointmentContentTypeTransferHandler extends AbstractTransferHandl
         resetRecurrenceTypeBasedFields(result);
         return result;
     }
+    
+    @Override
+    protected void addTimeLimitParameters(Map<String, String> parameters, Session session) {
+        parameters.put(CommonConstants.START, String.valueOf(session.getCalendarStartDate()));
+        parameters.put(CommonConstants.END, String.valueOf(session.getCalendarEndDate()));
+    }
 
     @Override
     protected void addExtraTimestampListParameters(Map<String, String> parameters, Session session) {
@@ -184,12 +189,11 @@ public class AppointmentContentTypeTransferHandler extends AbstractTransferHandl
 
     public DataObject[] getAllAppointments(Session session, BitSet requestedFields) throws USMException {
         if (LOG.isDebugEnabled())
-            LOG.debug(session + " Getting new appointments for date range " + session.getStartDate() + " - " + session.getEndDate());
+            LOG.debug(session + " Getting new appointments for date range " + session.getCalendarStartDate() + " - " + session.getCalendarEndDate());
         Map<String, String> parameters = new HashMap<String, String>();
 
         parameters.put(CommonConstants.COLUMNS, createColumnsParameter(requestedFields));
-        parameters.put(CommonConstants.START, String.valueOf(session.getStartDate()));
-        parameters.put(CommonConstants.END, String.valueOf(session.getEndDate()));
+        addTimeLimitParameters(parameters, session);
         addExtraTimestampListParameters(parameters, session);
         addObjectsLimitParameters(session, parameters);
 
@@ -199,7 +203,7 @@ public class AppointmentContentTypeTransferHandler extends AbstractTransferHandl
     }
 
     public DataObject[] getAllRecurrencesAsAppointments(Session session, BitSet requestedFields, DataObject seriesObject) throws USMException {
-        return getAllRecurrencesAsAppointments(session, requestedFields, seriesObject, session.getStartDate(), session.getEndDate());
+        return getAllRecurrencesAsAppointments(session, requestedFields, seriesObject, session.getCalendarStartDate(), session.getCalendarEndDate());
     }
 
     public DataObject[] getAllRecurrencesAsAppointments(Session session, BitSet requestedFields, DataObject seriesObject, long startDate, long endDate) throws USMException {
@@ -208,8 +212,7 @@ public class AppointmentContentTypeTransferHandler extends AbstractTransferHandl
         Map<String, String> parameters = new HashMap<String, String>();
 
         parameters.put(CommonConstants.COLUMNS, createColumnsParameter(requestedFields));
-        parameters.put(CommonConstants.START, String.valueOf(startDate));
-        parameters.put(CommonConstants.END, String.valueOf(endDate));
+        addTimeLimitParameters(parameters, session);
         String folder = seriesObject != null ? seriesObject.getParentFolderID() : null;
         if (folder != null)
             parameters.put(CommonConstants.FOLDER, folder);
@@ -618,8 +621,8 @@ public class AppointmentContentTypeTransferHandler extends AbstractTransferHandl
             CommonConstants.FOLDER,
             null,
             null,
-            String.valueOf(session.getStartDate()),
-            String.valueOf(session.getEndDate()));
+            String.valueOf(session.getCalendarStartDate()),
+            String.valueOf(session.getCalendarEndDate()));
         resetRecurrenceTypeBasedFields(result);
         return result;
     }
