@@ -55,33 +55,37 @@ import com.openexchange.usm.api.datatypes.AbstractDataType;
 import com.openexchange.usm.api.session.Session;
 
 public class ContactDistributionMemberDataType extends AbstractDataType<ContactDistributionMember> {
-	public static final String NAME = "ContactDistributionMember";
+	
+    public ContactDistributionMemberDataType() {
+        super("ContactDistributionMember");
+    }
 
-	public void addToJSONArray(Session session, JSONArray parent, Object value) throws JSONException {
+	@Override
+    public void addToJSONArray(Session session, JSONArray parent, Object value) throws JSONException {
 		parent.put(((ContactDistributionMember) value).toJSONObject());
 	}
 
-	public ContactDistributionMember checkValue(Object o) {
+	@Override
+    public ContactDistributionMember checkValue(Object o) {
 		if (o != null && !(o instanceof ContactDistributionMember))
 			generateTypeError(o);
 		return (ContactDistributionMember) o;
 	}
 
-	public ContactDistributionMember extractFromJSONArray(Session session, JSONArray array, int index)
+	@Override
+    public ContactDistributionMember extractFromJSONArray(Session session, JSONArray array, int index)
 			throws JSONException {
 		return array.isNull(index) ? new ContactDistributionMember() : new ContactDistributionMember(array.getJSONObject(index));
 	}
 
-	public ContactDistributionMember extractFromJSONObject(Session session, JSONObject jsonObject, String field)
+	@Override
+    public ContactDistributionMember extractFromJSONObject(Session session, JSONObject jsonObject, String field)
 			throws JSONException {
 		return jsonObject.isNull(field) ? new ContactDistributionMember() : new ContactDistributionMember(jsonObject.getJSONObject(field));
 	}
 
-	public String getName() {
-		return NAME;
-	}
-
-	public void storeInJSONObject(Session session, JSONObject parent, String field, Object value) throws JSONException {
+	@Override
+    public void storeInJSONObject(Session session, JSONObject parent, String field, Object value) throws JSONException {
 		parent.put(field, ((ContactDistributionMember) value).toJSONObject());
 	}
 }
