@@ -176,7 +176,18 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
     }
 
     public ResourceInputStream getMailAttachmentAsStream(Session session, String folderId, String mailId, String attachmentId) throws USMException {
+        return getMailAttachmentAsStream(session, folderId, mailId, attachmentId, false);
+    }
+
+    public ResourceInputStream getMailAttachmentAsStreamFromStructureId(Session session, String folderId, String mailId, String structureId) throws USMException {
+        return getMailAttachmentAsStream(session, folderId, mailId, structureId, true);
+    }
+
+    private ResourceInputStream getMailAttachmentAsStream(Session session, String folderId, String mailId, String attachmentId, boolean fromStructure) throws USMException {
         Map<String, String> parameters = createMailAttachmentParameters(folderId, mailId, attachmentId);
+        if (fromStructure) {
+            parameters.put("from_structure", "true");
+        }
         ResourceInputStream result = _ajaxAccess.getResourceAsStream(session, CommonConstants.MAIL_PATH, parameters);
         return result;
     }
