@@ -55,31 +55,35 @@ import com.openexchange.usm.api.datatypes.AbstractDataType;
 import com.openexchange.usm.api.session.Session;
 
 public class HeadersDataType extends AbstractDataType<Headers> {
-	public static final String NAME = "Headers";
+	
+    public HeadersDataType() {
+	    super("Headers");
+	}
 
-	public void addToJSONArray(Session session, JSONArray parent, Object value) throws JSONException {
+	@Override
+    public void addToJSONArray(Session session, JSONArray parent, Object value) throws JSONException {
 		parent.put((value == null) ? new JSONObject() : ((Headers) value).toJSONObject());
 	}
 
-	public Headers checkValue(Object o) {
+	@Override
+    public Headers checkValue(Object o) {
 		if (o != null && !(o instanceof Headers))
 			generateTypeError(o);
 		return (Headers) o;
 	}
 
-	public Headers extractFromJSONArray(Session session, JSONArray array, int index) throws JSONException {
+	@Override
+    public Headers extractFromJSONArray(Session session, JSONArray array, int index) throws JSONException {
 		return array.isNull(index) ? new Headers() : new Headers(array.optJSONObject(index));
 	}
 
-	public Headers extractFromJSONObject(Session session, JSONObject jsonObject, String field) throws JSONException {
+	@Override
+    public Headers extractFromJSONObject(Session session, JSONObject jsonObject, String field) throws JSONException {
 		return jsonObject.isNull(field) ? new Headers() : new Headers(jsonObject.optJSONObject(field));
 	}
 
-	public String getName() {
-		return NAME;
-	}
-
-	public void storeInJSONObject(Session session, JSONObject parent, String field, Object value) throws JSONException {
+	@Override
+    public void storeInJSONObject(Session session, JSONObject parent, String field, Object value) throws JSONException {
 		if (value instanceof Headers)
 			parent.put(field, ((Headers) value).toJSONObject());
 		else
