@@ -55,32 +55,36 @@ import com.openexchange.usm.api.datatypes.AbstractDataType;
 import com.openexchange.usm.api.session.Session;
 
 public class ParticipantIdentifierDataType extends AbstractDataType<ParticipantIdentifier> {
-	public static final String NAME = "ParticipantIdentifier";
+	
+    public ParticipantIdentifierDataType() {
+	    super("ParticipantIdentifier");
+	}
 
-	public void addToJSONArray(Session session, JSONArray parent, Object value) throws JSONException {
+	@Override
+    public void addToJSONArray(Session session, JSONArray parent, Object value) throws JSONException {
 		parent.put(((ParticipantIdentifier) value).toJSONObject());
 	}
 
-	public ParticipantIdentifier checkValue(Object o) {
+	@Override
+    public ParticipantIdentifier checkValue(Object o) {
 		if (o != null && !(o instanceof ParticipantIdentifier))
 			generateTypeError(o);
 		return (ParticipantIdentifier) o;
 	}
 
-	public ParticipantIdentifier extractFromJSONArray(Session session, JSONArray array, int index) throws JSONException {
+	@Override
+    public ParticipantIdentifier extractFromJSONArray(Session session, JSONArray array, int index) throws JSONException {
 		return array.isNull(index) ? new ParticipantIdentifier() : new ParticipantIdentifier(array.getJSONObject(index));
 	}
 
-	public ParticipantIdentifier extractFromJSONObject(Session session, JSONObject jsonObject, String field)
+	@Override
+    public ParticipantIdentifier extractFromJSONObject(Session session, JSONObject jsonObject, String field)
 			throws JSONException {
 		return jsonObject.isNull(field) ? new ParticipantIdentifier() : new ParticipantIdentifier(jsonObject.getJSONObject(field));
 	}
 
-	public String getName() {
-		return NAME;
-	}
-
-	public void storeInJSONObject(Session session, JSONObject parent, String field, Object value) throws JSONException {
+	@Override
+    public void storeInJSONObject(Session session, JSONObject parent, String field, Object value) throws JSONException {
 		parent.put(field, ((ParticipantIdentifier) value).toJSONObject());
 	}
 }
