@@ -50,21 +50,22 @@
 package com.openexchange.usm.database.ox;
 
 import com.openexchange.exception.Category;
+import com.openexchange.exception.DisplayableOXExceptionCode;
 import com.openexchange.exception.OXException;
-import com.openexchange.exception.OXExceptionCode;
 import com.openexchange.exception.OXExceptionFactory;
+import com.openexchange.exception.OXExceptionStrings;
 
 /**
  * Defines all error messages for the LoginException.
- * 
+ *
  * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
  */
-public enum USMUpdateExceptionCodes implements OXExceptionCode {
+public enum USMUpdateExceptionCodes implements DisplayableOXExceptionCode {
 
 	/**
 	 * SQL error while adding USM tables
 	 */
-	SQL_ERROR(USMUpdateExceptionMessages.SQL_ERROR_MSG, CATEGORY_SERVICE_DOWN, 0);
+	SQL_ERROR("SQL error while adding USM tables", CATEGORY_SERVICE_DOWN, 0, OXExceptionStrings.SQL_ERROR_MSG);
 
 	private final String message;
 
@@ -72,35 +73,48 @@ public enum USMUpdateExceptionCodes implements OXExceptionCode {
 
     private final Category category;
 
-    private USMUpdateExceptionCodes(final String message, final Category category, final int detailNumber) {
+    private final String displayMessage;
+
+    private USMUpdateExceptionCodes(final String message, final Category category, final int detailNumber, final String displayMessage) {
         this.message = message;
         this.detailNumber = detailNumber;
         this.category = category;
+        this.displayMessage = displayMessage != null ? displayMessage : OXExceptionStrings.MESSAGE;
     }
 
+    @Override
     public String getMessage() {
         return message;
     }
 
+    @Override
     public Category getCategory() {
         return category;
     }
 
+    @Override
     public int getNumber() {
         return detailNumber;
     }
 
+    @Override
+    public String getDisplayMessage() {
+        return displayMessage;
+    }
+
+    @Override
     public String getPrefix() {
         return "SRV";
     }
 
+    @Override
     public boolean equals(final OXException e) {
         return OXExceptionFactory.getInstance().equals(this, e);
     }
 
     /**
      * Creates a new {@link OXException} instance pre-filled with this code's attributes.
-     * 
+     *
      * @return The newly created {@link OXException} instance
      */
     public OXException create() {
@@ -109,7 +123,7 @@ public enum USMUpdateExceptionCodes implements OXExceptionCode {
 
     /**
      * Creates a new {@link OXException} instance pre-filled with this code's attributes.
-     * 
+     *
      * @param args The message arguments in case of printf-style message
      * @return The newly created {@link OXException} instance
      */
@@ -119,7 +133,7 @@ public enum USMUpdateExceptionCodes implements OXExceptionCode {
 
     /**
      * Creates a new {@link OXException} instance pre-filled with this code's attributes.
-     * 
+     *
      * @param cause The optional initial cause
      * @param args The message arguments in case of printf-style message
      * @return The newly created {@link OXException} instance
