@@ -62,6 +62,8 @@ public class CommandConstants {
 	public static final String TIME_ZONE = "timezone";
 	public static final String START_DATE = "startDate";
 	public static final String END_DATE = "endDate";
+	public static final String START_DATE_CALENDAR = "startDateCalendar";
+    public static final String END_DATE_CALENDAR = "endDateCalendar";
 	public static final String FOLDER_TREE = "tree";
 	public static final String CONFLICT_RESOLUTION = "conflictResolution";
 	public static final String CUSTOM_PROPERTIES = "customProperties";
