@@ -50,6 +50,7 @@
 package com.openexchange.usm.connector.commands;
 
 import static com.openexchange.usm.connector.commands.CommandConstants.*;
+import java.io.EOFException;
 import java.io.IOException;
 import java.io.Writer;
 import javax.servlet.http.HttpServletRequest;
@@ -191,8 +192,19 @@ public class DownloadDataHandler extends NormalCommandHandler {
     }
 
     private void skipOffset(ResourceInputStream is) throws IOException {
-        for (long remaining = _offset; remaining > 0; remaining -= is.skip(remaining))
-            ;
+        long skipped =0L, remaining = _offset;
+        
+        for (; remaining > 0; remaining -= skipped) {
+            skipped = is.skip(remaining);
+            if (skipped <= 0) {
+                break;
+            }
+        }
+        for (; remaining > 0L; remaining--) {
+            if (is.read() == -1) {
+                throw new EOFException("EOF reached while skipping " + _offset + " bytes");
+            }
+        }
     }
 
     private void writeResponse(ResourceInputStream is, Writer w) throws IOException {
@@ -287,7 +299,7 @@ public class DownloadDataHandler extends NormalCommandHandler {
                 return _object.getContentType().getTransferHandler().getAttachmentDataStream(_object, attachmentId, _offset, _realLength);
             }
             MailContentType mailContentType = (MailContentType) _object.getContentType();
-            return mailContentType.getMailAttachmentAsStream(_session, _id.getFolderId(), _id.getObjectId(), _id.getAttachmentId());
+            return mailContentType.getMailAttachmentStreamFromStructureId(_session, _id.getFolderId(), _id.getObjectId(), _id.getAttachmentId());
         } catch (NumberFormatException ignored) {
             throw new USMJSONAPIException(
                 ConnectorBundleErrorCodes.DOWNLOAD_DATA_INVALID_ATTACHMENT_ID,
