@@ -95,9 +95,11 @@ public class InvalidateObjectsHandler extends NormalCommandHandler {
 		try {
 			DataObject[] objects = null;
 			String folderID = null;
+			boolean invalidatingFolders = false;
 			if (folderUUID == null) {
 				//client has sent folders in the objects list
 				objects = _session.getCachedFolders(syncID);
+				invalidatingFolders = true;
 			} else {
 				try {
 					Folder folder = getFolderByUUID(folderUUID);
@@ -117,6 +119,8 @@ public class InvalidateObjectsHandler extends NormalCommandHandler {
 				String uuid = objectUUIDs.getString(i);
 				DataObject removedObj = objectsSet.remove(UUID.fromString(uuid));
 				resultData.put(uuid, (removedObj == null) ? NOT_FOUND : "ok");
+				if(invalidatingFolders)
+				    removeSubfoldersFromSyncedFoldersSet(removedObj, objectsSet, new DataObjectSet(objectsSet));
 			}
 			long newSyncID = (folderUUID == null) ? _session.storeSyncState(syncID, syncID, objectsSet.toArray())
 					: _session.storeSyncState(syncID, syncID, folderID, objectsSet.toArray());
@@ -136,6 +140,15 @@ public class InvalidateObjectsHandler extends NormalCommandHandler {
 					e);
 		}
 	}
+	
+	private void removeSubfoldersFromSyncedFoldersSet (DataObject parentFolder, DataObjectSet objectSet, DataObjectSet copyObjectSet) {
+	    for (DataObject dataObject : copyObjectSet) {
+            if(dataObject.getParentFolderID().equals(parentFolder.getID())) {
+                objectSet.remove(dataObject.getID());
+                removeSubfoldersFromSyncedFoldersSet(dataObject, objectSet, copyObjectSet);
+            }
+	    }
+	}
 
 	@Override
 	protected String[] getOptionalParameters() {
