@@ -49,7 +49,16 @@
 
 package com.openexchange.usm.connector.commands;
 
-import static com.openexchange.usm.connector.commands.CommandConstants.*;
+import static com.openexchange.usm.connector.commands.CommandConstants.AVAILABLE_CONTENT_TYPES;
+import static com.openexchange.usm.connector.commands.CommandConstants.CONFIGURATION;
+import static com.openexchange.usm.connector.commands.CommandConstants.DEVICE;
+import static com.openexchange.usm.connector.commands.CommandConstants.LOCAL_TIME;
+import static com.openexchange.usm.connector.commands.CommandConstants.PASSWORD;
+import static com.openexchange.usm.connector.commands.CommandConstants.SESSIONID;
+import static com.openexchange.usm.connector.commands.CommandConstants.SYNC_CONTENT_TYPES;
+import static com.openexchange.usm.connector.commands.CommandConstants.USER;
+import static com.openexchange.usm.connector.commands.CommandConstants.USERID;
+import static com.openexchange.usm.connector.commands.CommandConstants.VERSION;
 import java.text.SimpleDateFormat;
 import java.util.Date;
 import java.util.TimeZone;
