@@ -57,7 +57,6 @@ import static com.openexchange.usm.connector.commands.CommandConstants.SOURCESYN
 import static com.openexchange.usm.json.response.ResponseObject.ERROR_DETAILS;
 import static com.openexchange.usm.json.response.ResponseObject.ERROR_MESSAGE;
 import static com.openexchange.usm.json.response.ResponseObject.ERROR_STATUS;
-
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.BitSet;
@@ -65,14 +64,12 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
-
 import javax.servlet.http.HttpServletRequest;
-
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
-
 import com.openexchange.usm.api.contenttypes.common.DefaultContentTypes;
+import com.openexchange.usm.api.contenttypes.mail.MailContentType;
 import com.openexchange.usm.api.database.StorageAccessException;
 import com.openexchange.usm.api.exceptions.OperationDeniedException;
 import com.openexchange.usm.api.exceptions.USMException;
@@ -109,29 +106,29 @@ public class MoveItemsHandler extends NormalCommandHandler {
     public MoveItemsHandler(USMJSONServlet servlet, HttpServletRequest request) throws USMJSONAPIException {
         super(servlet, request);
     }
-	
+
 	private class ErrorObject {
-	    
+
 	    private JSONObject _errorDetails;
 	    private ErrorStatusCode _errorStatusCode;
 	    private DataObject _dataObject;
-	    
+
         public ErrorObject(JSONObject _errorDetails, ErrorStatusCode _errorStatusCode, DataObject _dataObject) {
             this._errorDetails = _errorDetails;
             this._errorStatusCode = _errorStatusCode;
             this._dataObject = _dataObject;
         }
 
-        
+
         public JSONObject getErrorDetails() {
             return _errorDetails;
         }
 
-        
+
         public ErrorStatusCode getErrorStatusCode() {
             return _errorStatusCode;
         }
-        
+
         public DataObject getDataObject() {
             return _dataObject;
         }
@@ -151,7 +148,7 @@ public class MoveItemsHandler extends NormalCommandHandler {
                     "Source and Destination are the same.",
                     sourceFolderUUID,
                     destinationFolderUUID));
-        
+
         String acquirer = "moveItems:" + sourceFolderUUID + " -> " + destinationFolderUUID;
         String previousAcquirer = _session.tryLock(sourceFolderUUID, acquirer);
         if (previousAcquirer != null)
@@ -163,11 +160,16 @@ public class MoveItemsHandler extends NormalCommandHandler {
             try {
                 Folder sourceFolder = getFolderByUUID(sourceFolderUUID);
                 Folder destinationFolder = getFolderByUUID(destinationFolderUUID);
-           
+
                 JSONArray objectsToMove = getJSONArray(_parameters, OBJECTIDS);
                 // move items
                 JSONObject response = moveItems(sourceFolder, destinationFolder, objectsToMove);
-                
+
+                if (DefaultContentTypes.MAIL_CODE == sourceFolder.getElementsContentType().getCode())  {
+                    // for mail folders a move of items results in a change of the folder hierarchy
+                    _session.invalidateCachedData(null);
+                }
+
                 long sourceFolderSyncID = getLongParameter(SOURCESYNCID, 0L);
                 long destinationSyncID = getLongParameter(DESTINATIONSYNCID, 0L);
                 if(sourceFolderSyncID > 0 || destinationSyncID > 0) {
@@ -198,7 +200,7 @@ public class MoveItemsHandler extends NormalCommandHandler {
 	private String generateErrorMessage(String message, Folder source, Folder dest) {
 		return message + '(' + source.getUUID() + '/' + source.getID()  + "->" + dest.getUUID()	+ '/' + dest.getID()  + ')';
 	}
-	
+
 	private String generateErrorMessage(String message, String sourceUUID, String destUUID) {
         return message + '(' + sourceUUID  + "->" + destUUID + ')';
     }
@@ -235,7 +237,7 @@ public class MoveItemsHandler extends NormalCommandHandler {
                 } catch (USMException e) {
                     if(isObjectMissingInSourceFolder(e.getOxErrorForJSONResponse()))
                         addErrorToMap(uuidString, null , e, ErrorStatusCode.OBJECT_DOES_NOT_EXIST_IN_SOURCE);
-                    else 
+                    else
                         addErrorToMap(uuidString, null, e, ErrorStatusCode.OTHER);
                 }
             }
@@ -247,7 +249,7 @@ public class MoveItemsHandler extends NormalCommandHandler {
                     updateErrorsMap.put(dataObject, e);
                 }
             }
-			
+
             if (DefaultContentTypes.MAIL_CODE == destinationFolder.getElementsContentType().getCode() || DefaultContentTypes.MAIL_ID.equals(destinationFolder.getElementsContentTypeID())) { // for mail folders we still have to modify the last sync states - otherwise the mail will be duplicated at the destination
                 DataObject[] newDestinationState = getNewDestinationStateToSave(destinationFolder, changesList, updateErrorsMap);
                 long newestTimestamp = _session.getNewestTimestamp(destinationFolder.getID());
@@ -258,9 +260,9 @@ public class MoveItemsHandler extends NormalCommandHandler {
                     newDestinationState);
                 responseData.put(DESTINATIONSYNCID, newDestinationSyncID);
             }
-			
+
 			initializeErrorMap(updateErrorsMap);
-			
+
 			if (!_errorsMap.isEmpty()) {
 				JSONObject notmoved = new JSONObject();
 				//reset to other
@@ -283,12 +285,12 @@ public class MoveItemsHandler extends NormalCommandHandler {
         }
 		return responseData;
 	}
-	
+
 	private boolean isObjectMissingInSourceFolder(JSONObject oxError) {
 	    return OXJSONUtil.isMissingObjectErrorCode(oxError);
 	}
-	
-	
+
+
 	private DataObject[] getNewDestinationStateToSave(Folder folder, List<DataObject> requestedChanges, Map<DataObject, USMException> updateErrorsMap)
         throws USMException {
     DataObject[] oldState = _session.getCachedFolderElements(folder.getID(), folder.getElementsContentType());
@@ -308,7 +310,7 @@ public class MoveItemsHandler extends NormalCommandHandler {
         }
     return resultList.toArray(new DataObject[resultList.size()]);
 }
-	
+
 	private void initializeErrorMap(Map<DataObject, USMException> updateResultMap) throws JSONException {
         for (Map.Entry<DataObject, USMException> entry : updateResultMap.entrySet()) {
             DataObject object = entry.getKey();
@@ -342,13 +344,13 @@ public class MoveItemsHandler extends NormalCommandHandler {
 	private void addErrorToNotMovedArray(int sourceRights, int destinationRights, JSONObject notmoved, String uuid,
 			ErrorObject error) throws JSONException {
 		JSONObject errorObject = new JSONObject();
-		
+
 		errorObject.put(ERROR_DETAILS, error.getErrorDetails());
 		errorObject.put(ERROR_STATUS, getErrorStatusCode(destinationRights, sourceRights, error.getDataObject(), error.getErrorStatusCode())
 				.getStatusCode());
 		notmoved.put(uuid, errorObject);
 	}
-	
+
     private void addErrorToMap(String uuid, DataObject dataObject, USMException exception, ErrorStatusCode errorStatus) throws JSONException {
         JSONObject details = exception.getErrorDetailsForJSONResponse();
         if (details == null)
