@@ -97,6 +97,8 @@ import com.openexchange.usm.util.Toolkit;
 
 public abstract class NormalCommandHandler extends BaseCommandHandler {
 
+    protected static final String GLOBAL_ADDRESS_BOOK_ID = "F_6";
+
     private static final String DELETE_EXCEPTIONS = "delete_exceptions";
     
     private static final String OWN_RIGHTS = "own_rights";
@@ -105,6 +107,8 @@ public abstract class NormalCommandHandler extends BaseCommandHandler {
     
     // Used for MeetingRequests, to only search once for the default calendar folder if there are multiple MeetingRequests to sync
     protected Folder _defaultCalendarFolder = null;
+    
+    protected Folder _defaultConcatcsFolder = null;
 
     protected NormalCommandHandler(USMJSONServlet servlet, HttpServletRequest request) throws USMJSONAPIException {
         super(servlet, request);
@@ -219,7 +223,8 @@ public abstract class NormalCommandHandler extends BaseCommandHandler {
                         String user_id = dMember.getUser_id();
                         if (user_id != null) {
                             try {
-                                DataObject cachedListMember = o.getSession().getCachedFolderElement(getDefaultCalendarFolder().getID(), o.getContentType(), user_id);
+                                DataObject cachedListMember = getDefaultContacsFolder() != null ? o.getSession().getCachedFolderElement(getDefaultContacsFolder().getID(), o.getContentType(), user_id) : null;
+                                if (cachedListMember == null) cachedListMember = o.getSession().getCachedFolderElement(GLOBAL_ADDRESS_BOOK_ID, o.getContentType(), user_id);
                                 UUID uuid = cachedListMember != null ? cachedListMember.getUUID() : null;
                                 if (uuid != null) jObj.put(UUID_KEY, uuid.toString());
                             } catch (NumberFormatException ignored) {
@@ -305,7 +310,31 @@ public abstract class NormalCommandHandler extends BaseCommandHandler {
         }
         return null;
     }
+    
+    protected Folder getDefaultContacsFolder() throws StorageAccessException, USMStorageException {
+        if (_defaultConcatcsFolder == null)
+            _defaultConcatcsFolder = determineDefaultContacsFolder();
+        return _defaultConcatcsFolder;
+    }
 
+    private Folder determineDefaultContacsFolder() throws StorageAccessException, USMStorageException {
+        Folder[] folders = _session.getCachedFolders();
+        for (Folder f : folders) {
+            if (DefaultContentTypes.CONTACTS_ID.equals(f.getElementsContentTypeID())) {
+                Object v = f.getFieldContent(FolderConstants.STANDARD_FOLDER);
+                if (v instanceof Boolean) {
+                    if (((Boolean) v).booleanValue())
+                        return f;
+                } else {
+                    v = f.getFieldContent(FolderConstants.STANDARD_FOLDER_TYPE);
+                    if ((v instanceof Number) && ((Number) v).intValue() == FolderConstants.DEFAULT_CONTACTS_FOLDER)
+                        return f;
+                }
+            }
+        }
+        return null;
+    }
+    
     private boolean isParentFolderShared(DataObject o) throws USMJSONAPIException {
         Folder parentFolder = o.getParentFolder();
         if (parentFolder == null)
@@ -345,7 +374,7 @@ public abstract class NormalCommandHandler extends BaseCommandHandler {
     }
 
     private boolean isChangeExceptionOutOfSyncRange(Object e) {
-        return ((Number) e).longValue() < _session.getStartDate() || ((Number) e).longValue() > _session.getEndDate();
+        return ((Number) e).longValue() < _session.getCalendarStartDate() || ((Number) e).longValue() > _session.getCalendarEndDate();
     }
 
 	protected boolean shouldIncludeFieldInClientResult(DataObject o, int i, DataType<?> fieldType, Object v,
