@@ -53,8 +53,8 @@ import static com.openexchange.usm.connector.commands.CommandConstants.MAIL;
 import static com.openexchange.usm.connector.commands.CommandConstants.SESSIONID;
 import javax.servlet.http.HttpServletRequest;
 import org.json.JSONObject;
-import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
-import com.openexchange.usm.api.contenttypes.MailContentType;
+import com.openexchange.usm.api.contenttypes.common.DefaultContentTypes;
+import com.openexchange.usm.api.contenttypes.mail.MailContentType;
 import com.openexchange.usm.api.exceptions.USMException;
 import com.openexchange.usm.api.io.InputStreamProvider;
 import com.openexchange.usm.json.ConnectorBundleErrorCodes;
