@@ -46,11 +46,22 @@
  *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  */
+
 package com.openexchange.usm.connector.commands;
 
-import static com.openexchange.usm.connector.commands.CommandConstants.*;
-import static com.openexchange.usm.json.ConnectorBundleErrorCodes.*;
+import static com.openexchange.usm.connector.commands.CommandConstants.CONFLICT_RESOLUTION;
+import static com.openexchange.usm.connector.commands.CommandConstants.CREATED;
+import static com.openexchange.usm.connector.commands.CommandConstants.DELETED;
+import static com.openexchange.usm.connector.commands.CommandConstants.DELETED_IF_EXIST;
+import static com.openexchange.usm.connector.commands.CommandConstants.FOLDERID;
+import static com.openexchange.usm.connector.commands.CommandConstants.LIMIT;
+import static com.openexchange.usm.connector.commands.CommandConstants.MODIFIED;
+import static com.openexchange.usm.connector.commands.CommandConstants.REFRESH;
+import static com.openexchange.usm.connector.commands.CommandConstants.SESSIONID;
+import static com.openexchange.usm.connector.commands.CommandConstants.SYNCID;
 import static com.openexchange.usm.json.response.ResponseStatusCode.*;
+import static com.openexchange.usm.json.ConnectorBundleErrorCodes.*;
+
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.BitSet;
@@ -60,25 +71,28 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.UUID;
+
 import javax.servlet.http.HttpServletRequest;
+
 import org.json.JSONArray;
 import org.json.JSONObject;
-import com.openexchange.usm.api.contenttypes.ContentType;
-import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
-import com.openexchange.usm.api.contenttypes.FolderConstants;
-import com.openexchange.usm.api.database.DatabaseAccessException;
+
+import com.openexchange.usm.api.contenttypes.common.ContentType;
+import com.openexchange.usm.api.contenttypes.common.DefaultContentTypes;
+import com.openexchange.usm.api.contenttypes.folder.FolderConstants;
+import com.openexchange.usm.api.database.StorageAccessException;
 import com.openexchange.usm.api.datatypes.DataType;
+import com.openexchange.usm.api.exceptions.InvalidUUIDException;
 import com.openexchange.usm.api.exceptions.USMException;
-import com.openexchange.usm.api.exceptions.USMSQLException;
-import com.openexchange.usm.api.session.ChangeState;
-import com.openexchange.usm.api.session.ConflictResolution;
+import com.openexchange.usm.api.exceptions.USMStorageException;
 import com.openexchange.usm.api.session.DataObject;
 import com.openexchange.usm.api.session.Folder;
-import com.openexchange.usm.api.session.SlowSyncRequiredException;
-import com.openexchange.usm.api.session.SyncResult;
-import com.openexchange.usm.api.session.SynchronizationConflictException;
+import com.openexchange.usm.api.session.assets.ChangeState;
+import com.openexchange.usm.api.session.assets.ConflictResolution;
+import com.openexchange.usm.api.session.assets.SyncResult;
+import com.openexchange.usm.api.session.exceptions.SlowSyncRequiredException;
+import com.openexchange.usm.api.session.exceptions.SynchronizationConflictException;
 import com.openexchange.usm.connector.exceptions.DataObjectNotFoundException;
-import com.openexchange.usm.connector.exceptions.InvalidUUIDException;
 import com.openexchange.usm.connector.exceptions.MultipleOperationsOnDataObjectException;
 import com.openexchange.usm.json.ConnectorBundleErrorCodes;
 import com.openexchange.usm.json.USMJSONAPIException;
@@ -88,43 +102,44 @@ import com.openexchange.usm.json.response.ResponseStatusCode;
 import com.openexchange.usm.session.dataobject.DataObjectSet;
 import com.openexchange.usm.session.dataobject.DataObjectUtil;
 import com.openexchange.usm.session.dataobject.FolderHierarchyComparator;
+import com.openexchange.usm.util.UUIDToolkit;
 
 /**
  * Handler for the SyncUpdate USM-JSON-Command.
+ * 
  * @author ldo
- *
  */
 public class SyncUpdateHandler extends SyncCommandHandler {
-	private static final String[] REQUIRED_PARAMETERS = { SESSIONID, SYNCID };
-	private static final String[] OPTIONAL_PARAMETERS = {
-			FOLDERID,
-			CREATED,
-			MODIFIED,
-			DELETED,
-			DELETED_IF_EXIST,
-			LIMIT,
-			CONFLICT_RESOLUTION,
-			REFRESH };
 
-	private static class MergeData {
-		public final DataObject _deletion;
-		public final DataObject _creation;
-		public final DataObject _change;
-		public boolean _errorOccurred;
+    private static final String[] REQUIRED_PARAMETERS = { SESSIONID, SYNCID };
 
-		private MergeData(DataObject deletion, DataObject creation, DataObject change) {
-			_deletion = deletion;
-			_creation = creation;
-			_change = change; // TODO Should we add the code to create the change object in this constructor ?
-		}
-	}
+    private static final String[] OPTIONAL_PARAMETERS = {
+        FOLDERID, CREATED, MODIFIED, DELETED, DELETED_IF_EXIST, LIMIT, CONFLICT_RESOLUTION, REFRESH };
 
-	private long _syncID;
-	private boolean _serverChangesMayBeAvailable;
+    private static class MergeData {
 
-	private final List<MergeData> _mergedCreationsAndDeletions = new ArrayList<MergeData>();
+        public final DataObject _deletion;
 
-	private final Set<UUID> _refreshUUIDs = new HashSet<UUID>();
+        public final DataObject _creation;
+
+        public final DataObject _change;
+
+        public boolean _errorOccurred;
+
+        private MergeData(DataObject deletion, DataObject creation, DataObject change) {
+            _deletion = deletion;
+            _creation = creation;
+            _change = change; // TODO Should we add the code to create the change object in this constructor ?
+        }
+    }
+
+    private long _syncID;
+
+    private boolean _serverChangesMayBeAvailable;
+
+    private final List<MergeData> _mergedCreationsAndDeletions = new ArrayList<MergeData>();
+
+    private final Set<UUID> _refreshUUIDs = new HashSet<UUID>();
 
     public SyncUpdateHandler(USMJSONServlet servlet, HttpServletRequest request) throws USMJSONAPIException {
         super(servlet, request);
@@ -206,7 +221,7 @@ public class SyncUpdateHandler extends SyncCommandHandler {
             for (int i = 0; i < size; i++) {
                 String uuid = getString(list, i);
                 try {
-                    _refreshUUIDs.add(extractUUIDFromString(uuid));
+                    _refreshUUIDs.add(UUIDToolkit.extractUUIDFromString(uuid));
                 } catch (InvalidUUIDException e) {
                     addError(uuid, null, e, ErrorStatusCode.UNKNOWN_UUID);
                 }
@@ -251,16 +266,19 @@ public class SyncUpdateHandler extends SyncCommandHandler {
 				: super.determineClientResultChangeState(o);
 	}
 
-	/**
-	 * If the UUID is present in the refresh parameter, always report all fields
-	 * If not, use normal behavior (i.e. non-default on creation, only modified fields for modifications)
-	 */
-	@Override
-	protected boolean shouldIncludeFieldInClientResult(DataObject o, int i, DataType<?> fieldType, Object v,
-			String fieldName) {
-		return _refreshUUIDs.contains(o.getUUID()) || isInClientChangesArray(o) ? true : super
-				.shouldIncludeFieldInClientResult(o, i, fieldType, v, fieldName);
-	}
+    /**
+     * If the UUID is present in the refresh parameter, always report all fields If not, use normal behavior (i.e. non-default on creation,
+     * only modified fields for modifications)
+     */
+    @Override
+    protected boolean shouldIncludeFieldInClientResult(DataObject o, int i, DataType<?> fieldType, Object v, String fieldName) {
+        return _refreshUUIDs.contains(o.getUUID()) || isInClientChangesArray(o) ? true : super.shouldIncludeFieldInClientResult(
+            o,
+            i,
+            fieldType,
+            v,
+            fieldName);
+    }
 
 	@Override
 	protected boolean shouldIncludeContactPicture(DataObject o) {
@@ -282,7 +300,7 @@ public class SyncUpdateHandler extends SyncCommandHandler {
 	}
 
 	@Override
-	protected void initializeCachedElements() throws DatabaseAccessException, USMSQLException {
+	protected void initializeCachedElements() throws StorageAccessException, USMStorageException {
 		_cachedElements.addAll(_session.getCachedFolderElements(_folderToSync.getID(), _folderToSync
 				.getElementsContentType(), _syncID));
 	}
@@ -301,8 +319,9 @@ public class SyncUpdateHandler extends SyncCommandHandler {
 		}
 	}
 
-	protected Folder[] _folderClientChangesArray;
+    protected Folder[] _folderClientChangesArray;
 
+   
 	private SyncResult computeSyncUpdate(String folderID, long syncId, ConflictResolution conflictResolution)
 			throws USMJSONAPIException {
 		try {
@@ -340,6 +359,7 @@ public class SyncUpdateHandler extends SyncCommandHandler {
 		}
 	}
 
+   
     private BitSet getStandardFolderDeletionsFromSyncResult() {
         BitSet deletedStandardFolders = new BitSet(); // all standard folder types that were deleted
         BitSet createdStandardFolders = new BitSet(); // all standard folder types that were created
@@ -396,7 +416,7 @@ public class SyncUpdateHandler extends SyncCommandHandler {
         return 0;
     }
 
-    private Folder[] createFolderChangesArray(long syncId) throws DatabaseAccessException, USMSQLException,
+    private Folder[] createFolderChangesArray(long syncId) throws StorageAccessException, USMStorageException,
 			USMJSONAPIException, SlowSyncRequiredException {
 		Folder[] originalFolders = _session.getCachedFolders(syncId);
 		if (originalFolders == null)
@@ -419,98 +439,94 @@ public class SyncUpdateHandler extends SyncCommandHandler {
 		return result;
 	}
 
-	private DataObject[] buildClientRequestArray(Folder folder, long syncId, ConflictResolution conflictResolution)
-			throws USMException {
-		DataObject[] originalElements = _session.getCachedFolderElements(folder.getID(), folder
-				.getElementsContentType(), syncId);
-		if (originalElements == null)
-			throw new SlowSyncRequiredException(-1, null);
-		ContentType elementsContentType = folder.getElementsContentType();
-		if (elementsContentType == null)
-			return EMPTY_DATAOBJECT_ARRAY;
-		DataObject[] createdElements = readCreatedFolderElements(folder, syncId, conflictResolution, originalElements);
-		DataObject[] modifiedElements;
-		if (elementsContentType.getCode() == DefaultContentTypes.MAIL_CODE) {
-			modifiedElements = readModifiedMailDataObjects(folder, elementsContentType, originalElements, syncId);
-		} else {
-			modifiedElements = readModifiedFolderElements(folder, originalElements, createdElements);
-		}
-		DataObject[] deletedElements = readDeletedFolderElements(originalElements);
-		if (createdElements.length == 0 || deletedElements.length == 0 || !isTaskOrAppointmentType(elementsContentType))
-			return buildSimpleClientRequestArray(createdElements, modifiedElements, deletedElements);
-		return buildComplexClientRequestArray(createdElements, modifiedElements, deletedElements);
-	}
+    private DataObject[] buildClientRequestArray(Folder folder, long syncId, ConflictResolution conflictResolution) throws USMException {
+        DataObject[] originalElements = _session.getCachedFolderElements(folder.getID(), folder.getElementsContentType(), syncId);
+        if (originalElements == null)
+            throw new SlowSyncRequiredException(-1, null);
+        ContentType elementsContentType = folder.getElementsContentType();
+        if (elementsContentType == null)
+            return EMPTY_DATAOBJECT_ARRAY;
+        DataObject[] createdElements = readCreatedFolderElements(folder, syncId, conflictResolution, originalElements);
+        DataObject[] modifiedElements;
+        if (elementsContentType.getCode() == DefaultContentTypes.MAIL_CODE) {
+            modifiedElements = readModifiedMailDataObjects(folder, elementsContentType, originalElements, syncId);
+        } else {
+            modifiedElements = readModifiedFolderElements(folder, originalElements, createdElements);
+        }
+        DataObject[] deletedElements = readDeletedFolderElements(originalElements);
+        if (createdElements.length == 0 || deletedElements.length == 0 || !isTaskOrAppointmentType(elementsContentType))
+            return buildSimpleClientRequestArray(createdElements, modifiedElements, deletedElements);
+        return buildComplexClientRequestArray(createdElements, modifiedElements, deletedElements);
+    }
 
-	private DataObject[] buildComplexClientRequestArray(DataObject[] createdElements, DataObject[] modifiedElements,
-			DataObject[] deletedElements) {
-		List<DataObject> result = new ArrayList<DataObject>();
-		Map<String, DataObject> deletions = new HashMap<String, DataObject>();
-		for (DataObject deletion : deletedElements) {
-			String uid = getUID(deletion);
-			if (uid != null)
-				deletions.put(uid, deletion);
-			else
-				result.add(deletion);
-		}
-		for (DataObject object : modifiedElements) {
-			result.add(object);
-		}
-		for (DataObject creation : createdElements) {
-			String uid = getUID(creation);
-			if (uid != null) {
-				DataObject deletion = deletions.remove(uid);
-				if (deletion == null) {
-					result.add(creation);
-				} else {
-					// Create copy of original object in SyncState
-					DataObject change = deletion.createCopy(false);
-					change.rollbackChanges();
-					// Apply all fields from the creation so that they will become changes in the new change object
-					DataObjectUtil.modify(change, creation);
-					// Make sure the OX ID is switched back to the original ID so that the sync system can find the object on the server
-					change.setID(deletion.getID());
-					_mergedCreationsAndDeletions.add(new MergeData(deletion, creation, change));
-					result.add(change);
-				}
-			} else {
-				result.add(creation);
-			}
-		}
-		for (DataObject deletion : deletions.values()) {
-			result.add(deletion);
-		}
-		return result.toArray(new DataObject[result.size()]);
-	}
+    private DataObject[] buildComplexClientRequestArray(DataObject[] createdElements, DataObject[] modifiedElements, DataObject[] deletedElements) {
+        List<DataObject> result = new ArrayList<DataObject>();
+        Map<String, DataObject> deletions = new HashMap<String, DataObject>();
+        for (DataObject deletion : deletedElements) {
+            String uid = getUID(deletion);
+            if (uid != null)
+                deletions.put(uid, deletion);
+            else
+                result.add(deletion);
+        }
+        for (DataObject object : modifiedElements) {
+            result.add(object);
+        }
+        for (DataObject creation : createdElements) {
+            String uid = getUID(creation);
+            if (uid != null) {
+                DataObject deletion = deletions.remove(uid);
+                if (deletion == null) {
+                    result.add(creation);
+                } else {
+                    // Create copy of original object in SyncState
+                    DataObject change = deletion.createCopy(false);
+                    change.rollbackChanges();
+                    // Apply all fields from the creation so that they will become changes in the new change object
+                    DataObjectUtil.modify(change, creation);
+                    // Make sure the OX ID is switched back to the original ID so that the sync system can find the object on the server
+                    change.setID(deletion.getID());
+                    _mergedCreationsAndDeletions.add(new MergeData(deletion, creation, change));
+                    result.add(change);
+                }
+            } else {
+                result.add(creation);
+            }
+        }
+        for (DataObject deletion : deletions.values()) {
+            result.add(deletion);
+        }
+        return result.toArray(new DataObject[result.size()]);
+    }
 
-	private DataObject[] buildSimpleClientRequestArray(DataObject[] createdElements, DataObject[] modifiedElements,
-			DataObject[] deletedElements) {
-		DataObject[] result = new DataObject[createdElements.length + modifiedElements.length + deletedElements.length];
-		int index = 0;
-		for (DataObject object : createdElements) {
-			result[index++] = object;
-		}
-		for (DataObject object : modifiedElements) {
-			result[index++] = object;
-		}
-		for (DataObject object : deletedElements) {
-			result[index++] = object;
-		}
-		return result;
-	}
+    private DataObject[] buildSimpleClientRequestArray(DataObject[] createdElements, DataObject[] modifiedElements, DataObject[] deletedElements) {
+        DataObject[] result = new DataObject[createdElements.length + modifiedElements.length + deletedElements.length];
+        int index = 0;
+        for (DataObject object : createdElements) {
+            result[index++] = object;
+        }
+        for (DataObject object : modifiedElements) {
+            result[index++] = object;
+        }
+        for (DataObject object : deletedElements) {
+            result[index++] = object;
+        }
+        return result;
+    }
 
-	private boolean isTaskOrAppointmentType(ContentType type) {
-		int code = type.getCode();
-		return code == DefaultContentTypes.CALENDAR_CODE || code == DefaultContentTypes.TASK_CODE;
-	}
+    private boolean isTaskOrAppointmentType(ContentType type) {
+        int code = type.getCode();
+        return code == DefaultContentTypes.CALENDAR_CODE || code == DefaultContentTypes.TASK_CODE;
+    }
 
-	private String getUID(DataObject o) {
-		try {
-			Object v = o.getFieldContent("uid");
-			return (v instanceof String) ? ((String) v) : null;
-		} catch (IllegalArgumentException iae) {
-			return null;
-		}
-	}
+    private String getUID(DataObject o) {
+        try {
+            Object v = o.getFieldContent("uid");
+            return (v instanceof String) ? ((String) v) : null;
+        } catch (IllegalArgumentException iae) {
+            return null;
+        }
+    }
 
     private DataObject[] readModifiedMailDataObjects(Folder folder, ContentType contentType, DataObject[] originalObjects, long syncId) throws USMException {
         if (!_parameters.has(MODIFIED))
@@ -536,15 +552,22 @@ public class SyncUpdateHandler extends SyncCommandHandler {
                 addError(uuidString, null, e, ErrorStatusCode.UNKNOWN_UUID);
                 continue;
             }
-			if (hasNoError(object)) {
-				try {
-					_syncIdForUpdate = updateMailObject(folder, originalObjects, syncId, result, data, object,
-							_syncIdForUpdate, syncStateToStore);
-				} catch (USMJSONAPIException e) {
-					addError(object, e);
-				}
-			}
-		}
+            if (hasNoError(object)) {
+                try {
+                    _syncIdForUpdate = updateMailObject(
+                        folder,
+                        originalObjects,
+                        syncId,
+                        result,
+                        data,
+                        object,
+                        _syncIdForUpdate,
+                        syncStateToStore);
+                } catch (USMJSONAPIException e) {
+                    addError(object, e);
+                }
+            }
+        }
         // if syncStateToStore contains objects from other folder, reset syncStateToStore to originalObjects
         if (containsForeignObjects(syncStateToStore, folder.getID()))
             syncStateToStore = originalObjects;
@@ -569,70 +592,70 @@ public class SyncUpdateHandler extends SyncCommandHandler {
         return result.toArray(new DataObject[result.size()]);
     }
 
-	private boolean containsForeignObjects(DataObject[] syncStateToStore, String folderId) {
-		for (DataObject dataObject : syncStateToStore) {
-			if (!folderId.equals(dataObject.getParentFolderID()))
-				return true;
-		}
-		return false;
-	}
+    private boolean containsForeignObjects(DataObject[] syncStateToStore, String folderId) {
+        for (DataObject dataObject : syncStateToStore) {
+            if (!folderId.equals(dataObject.getParentFolderID()))
+                return true;
+        }
+        return false;
+    }
 
-	@Override
-	protected String[] getOptionalParameters() {
-		return OPTIONAL_PARAMETERS;
-	}
+    @Override
+    protected String[] getOptionalParameters() {
+        return OPTIONAL_PARAMETERS;
+    }
 
-	@Override
-	protected String[] getRequiredParameters() {
-		return REQUIRED_PARAMETERS;
-	}
+    @Override
+    protected String[] getRequiredParameters() {
+        return REQUIRED_PARAMETERS;
+    }
 
-	@Override
-	protected long getOriginalSyncID() {
-		return _syncID;
-	}
+    @Override
+    protected long getOriginalSyncID() {
+        return _syncID;
+    }
 
-	@Override
-	protected long saveNewSyncState(SyncResult result, Folder folder, long syncId) throws USMJSONAPIException {
-		if (!_mergedCreationsAndDeletions.isEmpty()) {
-			for (MergeData md : _mergedCreationsAndDeletions) {
-				if (md._errorOccurred) {
-					// Undo changes in sync state
-					DataObject original = md._deletion.createCopy(false);
-					original.rollbackChanges();
-					_newStateToSave.remove(md._creation.getUUID());
-					_newStateToSave.add(original);
-				} else {
-					DataObject dataObject = _newStateToSave.get(md._deletion.getID());
-					if (dataObject != null)
-						dataObject.setUUID(md._creation.getUUID());
-					for (DataObject serverChange : result.getChanges()) {
-						if (md._deletion.getID().equals(serverChange.getID()))
-							serverChange.setUUID(md._creation.getUUID());
-					}
-				}
-			}
-			_newStateToSaveChanged = true;
-		}
-		return super.saveNewSyncState(result, folder, syncId);
-	}
+    @Override
+    protected long saveNewSyncState(SyncResult result, Folder folder, long syncId) throws USMJSONAPIException {
+        if (!_mergedCreationsAndDeletions.isEmpty()) {
+            for (MergeData md : _mergedCreationsAndDeletions) {
+                if (md._errorOccurred) {
+                    // Undo changes in sync state
+                    DataObject original = md._deletion.createCopy(false);
+                    original.rollbackChanges();
+                    _newStateToSave.remove(md._creation.getUUID());
+                    _newStateToSave.add(original);
+                } else {
+                    DataObject dataObject = _newStateToSave.get(md._deletion.getID());
+                    if (dataObject != null)
+                        dataObject.setUUID(md._creation.getUUID());
+                    for (DataObject serverChange : result.getChanges()) {
+                        if (md._deletion.getID().equals(serverChange.getID()))
+                            serverChange.setUUID(md._creation.getUUID());
+                    }
+                }
+            }
+            _newStateToSaveChanged = true;
+        }
+        return super.saveNewSyncState(result, folder, syncId);
+    }
 
-	@Override
-	protected void addError(UUID uuid, DataObject object, USMException error, ErrorStatusCode errorStatus) {
-		if (uuid == null)
-			uuid = object.getUUID();
-		if (uuid != null) {
-			if (!_mergedCreationsAndDeletions.isEmpty()) {
-				for (MergeData md : _mergedCreationsAndDeletions) {
-					if (uuid.equals(md._deletion.getUUID()) || uuid.equals(md._creation.getUUID())) {
-						md._errorOccurred = true;
-						addError(md._deletion.getUUID().toString(), object, error, errorStatus);
-						addError(md._creation.getUUID().toString(), object, error, errorStatus);
-						return;
-					}
-				}
-			}
-			addError(uuid.toString(), object, error, errorStatus);
-		}
-	}
+    @Override
+    protected void addError(UUID uuid, DataObject object, USMException error, ErrorStatusCode errorStatus) {
+        if (uuid == null)
+            uuid = object.getUUID();
+        if (uuid != null) {
+            if (!_mergedCreationsAndDeletions.isEmpty()) {
+                for (MergeData md : _mergedCreationsAndDeletions) {
+                    if (uuid.equals(md._deletion.getUUID()) || uuid.equals(md._creation.getUUID())) {
+                        md._errorOccurred = true;
+                        addError(md._deletion.getUUID().toString(), object, error, errorStatus);
+                        addError(md._creation.getUUID().toString(), object, error, errorStatus);
+                        return;
+                    }
+                }
+            }
+            addError(uuid.toString(), object, error, errorStatus);
+        }
+    }
 }
