@@ -46,44 +46,45 @@
  *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  */
+
 package com.openexchange.usm.connector.sync;
 
 import java.util.Comparator;
-import com.openexchange.usm.api.contenttypes.ContentType;
-import com.openexchange.usm.api.contenttypes.ContentTypeField;
+import com.openexchange.usm.api.contenttypes.common.ContentType;
+import com.openexchange.usm.api.contenttypes.common.ContentTypeField;
 import com.openexchange.usm.api.session.DataObject;
 
 public abstract class DataObjectSorter implements Comparator<DataObject> {
 
-	protected DataObjectSorter() {
-		super();
-	}
+    protected DataObjectSorter() {
+        super();
+    }
 
-	protected final int getFieldIndex(ContentType c, String field) {
-		ContentTypeField[] fields = c.getFields();
-		for (int i = 0; i < fields.length; i++) {
-			if (fields[i].getFieldName().equals(field))
-				return i;
-		}
-		throw new IllegalStateException("ContentType " + c.getID() + " has no field named " + field);
-	}
+    protected final int getFieldIndex(ContentType c, String field) {
+        ContentTypeField[] fields = c.getFields();
+        for (int i = 0; i < fields.length; i++) {
+            if (fields[i].getFieldName().equals(field))
+                return i;
+        }
+        throw new IllegalStateException("ContentType " + c.getID() + " has no field named " + field);
+    }
 
-	protected int compareTimestamp(DataObject o1, DataObject o2, int index) {
-		long l1 = getTimestamp(o1, index);
-		long l2 = getTimestamp(o2, index);
-		return (l1 > l2) ? -1 : (l1 < l2) ? 1 : 0;
-	}
+    protected int compareTimestamp(DataObject o1, DataObject o2, int index) {
+        long l1 = getTimestamp(o1, index);
+        long l2 = getTimestamp(o2, index);
+        return (l1 > l2) ? -1 : (l1 < l2) ? 1 : 0;
+    }
 
-	protected int compareString(DataObject o1, DataObject o2, int index) {
-		Object v1 = o1.getFieldContent(index);
-		Object v2 = o2.getFieldContent(index);
-		if (v1 == null)
-			return (v2 == null) ? 0 : -1;
-		return (v2 == null) ? 1 : v1.toString().compareTo(v2.toString());
-	}
+    protected int compareString(DataObject o1, DataObject o2, int index) {
+        Object v1 = o1.getFieldContent(index);
+        Object v2 = o2.getFieldContent(index);
+        if (v1 == null)
+            return (v2 == null) ? 0 : -1;
+        return (v2 == null) ? 1 : v1.toString().compareTo(v2.toString());
+    }
 
-	protected long getTimestamp(DataObject o1, int index) {
-		Object o = o1.getFieldContent(index);
-		return (o instanceof Number) ? ((Number) o).longValue() : 0L;
-	}
+    protected long getTimestamp(DataObject o1, int index) {
+        Object o = o1.getFieldContent(index);
+        return (o instanceof Number) ? ((Number) o).longValue() : 0L;
+    }
 }
