@@ -46,28 +46,32 @@
  *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  */
+
 package com.openexchange.usm.ox_json.impl;
 
 import org.json.JSONArray;
-import com.openexchange.usm.ox_json.JSONResultType;
+import com.openexchange.usm.api.ox.json.JSONResultType;
 
 public class JSONArrayResult extends AbstractJSONResult {
-	private final JSONArray _result;
 
-	public JSONArrayResult(JSONArray result) {
-		_result = result;
-	}
+    private final JSONArray _result;
 
-	@Override
-	public JSONArray getJSONArray() {
-		return _result;
-	}
+    public JSONArrayResult(JSONArray result) {
+        _result = result;
+    }
 
-	public String toJSONString() {
-		return _result.toString();
-	}
+    @Override
+    public JSONArray getJSONArray() {
+        return _result;
+    }
 
-	public JSONResultType getResultType() {
-		return JSONResultType.JSONArray;
-	}
+    @Override
+    public String toJSONString() {
+        return _result.toString();
+    }
+
+    @Override
+    public JSONResultType getResultType() {
+        return JSONResultType.JSONArray;
+    }
 }
