@@ -46,23 +46,25 @@
  *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  */
+
 package com.openexchange.usm.ox_json.impl;
 
 import org.json.JSONObject;
-import com.openexchange.usm.ox_json.JSONResultType;
+import com.openexchange.usm.api.ox.json.JSONResultType;
 
 public class JSONErrorResult extends JSONObjectResult {
-	public JSONErrorResult(JSONObject result) {
-		super(result);
-	}
 
-	@Override
-	public JSONResultType getResultType() {
-		return JSONResultType.Error;
-	}
+    public JSONErrorResult(JSONObject result) {
+        super(result);
+    }
 
-	@Override
-	public String toString() {
-		return "OX Error: " + toJSONString();
-	}
+    @Override
+    public JSONResultType getResultType() {
+        return JSONResultType.Error;
+    }
+
+    @Override
+    public String toString() {
+        return "OX Error: " + toJSONString();
+    }
 }
