@@ -46,28 +46,32 @@
  *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  */
+
 package com.openexchange.usm.ox_json.impl;
 
 import org.json.JSONObject;
-import com.openexchange.usm.ox_json.JSONResultType;
+import com.openexchange.usm.api.ox.json.JSONResultType;
 
 public class JSONObjectResult extends AbstractJSONResult {
-	private final JSONObject _jsonObject;
 
-	public JSONObjectResult(JSONObject result) {
-		_jsonObject = result;
-	}
+    private final JSONObject _jsonObject;
 
-	@Override
-	public JSONObject getJSONObject() {
-		return _jsonObject;
-	}
+    public JSONObjectResult(JSONObject result) {
+        _jsonObject = result;
+    }
 
-	public String toJSONString() {
-		return _jsonObject.toString();
-	}
+    @Override
+    public JSONObject getJSONObject() {
+        return _jsonObject;
+    }
 
-	public JSONResultType getResultType() {
-		return JSONResultType.JSONObject;
-	}
+    @Override
+    public String toJSONString() {
+        return _jsonObject.toString();
+    }
+
+    @Override
+    public JSONResultType getResultType() {
+        return JSONResultType.JSONObject;
+    }
 }
