@@ -46,28 +46,32 @@
  *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  */
+
 package com.openexchange.usm.ox_json.impl;
 
 import org.json.JSONObject;
-import com.openexchange.usm.ox_json.JSONResultType;
+import com.openexchange.usm.api.ox.json.JSONResultType;
 
 public class JSONStringResult extends AbstractJSONResult {
-	private final String _result;
 
-	public JSONStringResult(String result) {
-		_result = result;
-	}
+    private final String _result;
 
-	public JSONResultType getResultType() {
-		return JSONResultType.String;
-	}
+    public JSONStringResult(String result) {
+        _result = result;
+    }
 
-	public String toJSONString() {
-		return JSONObject.quote(_result);
-	}
+    @Override
+    public JSONResultType getResultType() {
+        return JSONResultType.String;
+    }
 
-	@Override
-	public String getString() {
-		return _result;
-	}
+    @Override
+    public String toJSONString() {
+        return JSONObject.quote(_result);
+    }
+
+    @Override
+    public String getString() {
+        return _result;
+    }
 }
