@@ -86,11 +86,12 @@ import org.apache.commons.httpclient.methods.multipart.StringPart;
 import org.apache.commons.httpclient.params.HttpConnectionManagerParams;
 import org.apache.commons.httpclient.params.HttpMethodParams;
 import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.usm.api.USMVersion;
-import com.openexchange.usm.api.contenttypes.ResourceInputStream;
+import com.openexchange.usm.api.contenttypes.resource.ResourceInputStream;
 import com.openexchange.usm.api.exceptions.AuthenticationFailedException;
 import com.openexchange.usm.api.exceptions.ConflictingChangeException;
 import com.openexchange.usm.api.exceptions.OXCommunicationException;
@@ -98,13 +99,13 @@ import com.openexchange.usm.api.exceptions.TemporaryDownOrBusyException;
 import com.openexchange.usm.api.exceptions.USMIllegalStateException;
 import com.openexchange.usm.api.exceptions.USMStartupException;
 import com.openexchange.usm.api.io.InputStreamProvider;
+import com.openexchange.usm.api.ox.json.JSONResult;
+import com.openexchange.usm.api.ox.json.JSONResultType;
+import com.openexchange.usm.api.ox.json.OXJSONAccess;
+import com.openexchange.usm.api.ox.json.OXJSONPropertyNames;
+import com.openexchange.usm.api.ox.json.OXResource;
 import com.openexchange.usm.api.session.OXConnectionInformation;
 import com.openexchange.usm.api.session.Session;
-import com.openexchange.usm.ox_json.JSONResult;
-import com.openexchange.usm.ox_json.JSONResultType;
-import com.openexchange.usm.ox_json.OXJSONAccess;
-import com.openexchange.usm.ox_json.OXJSONPropertyNames;
-import com.openexchange.usm.ox_json.OXResource;
 import com.openexchange.usm.util.OXJSONUtil;
 
 /**
@@ -157,7 +158,7 @@ public class OXJSONAccessImpl implements OXJSONAccess {
 
     private static final String USM_USER_AGENT = "Open-Xchange USM HTTP Client";
 
-    private Log _journal;
+    private static final Log LOG = LogFactory.getLog(OXJSONAccessImpl.class);
 
     private MultiThreadedHttpConnectionManager _httpManager;
 
@@ -173,26 +174,47 @@ public class OXJSONAccessImpl implements OXJSONAccess {
 
     private boolean _passClientHostHeader = false;
 
+    /**
+     * Initializes a new {@link OXJSONAccessImpl}.
+     * 
+     * @param oxJSONURL
+     * @param maxConnections
+     * @param connectionTimeout
+     * @param performStaleChecking
+     * @param passHostHeaderFromClient
+     */
+    public OXJSONAccessImpl(String oxJSONURL, int maxConnections, int connectionTimeout, boolean performStaleChecking, boolean passHostHeaderFromClient, String reloginErrorCodes) {
+        String error = doActivate(oxJSONURL, maxConnections, connectionTimeout, performStaleChecking, passHostHeaderFromClient, reloginErrorCodes);
+        if (error != null) {
+            error = "OXJSONAccess not activated, reason: " + error;
+            LOG.error(error);
+            deactivate(null);
+            throw new USMStartupException(OXJSONErrorCode.ACCESSIMPL_OXAJAXACCESS_NOTACTIVATED_ENCODING_NUMBER_8, error);
+        }
+    }
+
+    @Override
     public void login(Session session) throws AuthenticationFailedException, OXCommunicationException {
         logout(session, false);
         try {
             OXConnectionData result = obtainConnectionData(session);
-            if (_journal.isDebugEnabled())
-                _journal.debug(session + " Logged in, session id = " + result.getSessionID());
+            if (LOG.isDebugEnabled())
+                LOG.debug(session + " Logged in, session id = " + result.getSessionID());
         } catch (AuthenticationFailedException e) {
-            if (_journal.isDebugEnabled())
-                _journal.debug(session + " Authentication failed", e);
+            if (LOG.isDebugEnabled())
+                LOG.debug(session + " Authentication failed", e);
             throw e;
         } catch (OXCommunicationException e) {
-            _journal.warn(session + " Error while authenticating", e);
+            LOG.warn(session + " Error while authenticating", e);
             throw e;
         }
     }
 
+    @Override
     public JSONObject getConfiguration(Session session, String... path) throws AuthenticationFailedException, OXCommunicationException {
         JSONObject config = readConfiguration(session, path);
-        if (_journal.isDebugEnabled())
-            _journal.debug(session + " Retrieved OX ajax configuration");
+        if (LOG.isDebugEnabled())
+            LOG.debug(session + " Retrieved OX ajax configuration");
         return config;
     }
 
@@ -280,15 +302,16 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         return ("127.0.0.1".equals(session.getClientIp()) ? "" : ("&clientIP=" + session.getClientIp()));
     }
 
+    @Override
     public void logout(Session session) {
         logout(session, true);
     }
 
     private void logout(Session session, boolean doLog) {
-        if (doLog && _journal.isDebugEnabled())
-            _journal.debug(session + " Logging out");
+        if (doLog && LOG.isDebugEnabled())
+            LOG.debug(session + " Logging out");
         if (!obtainOptionalLock(session, "login?action=logout")) {
-            _journal.warn("Timeout while waiting to log out session " + session);
+            LOG.warn("Timeout while waiting to log out session " + session);
             session.setOXConnectionData(null);
             return;
         }
@@ -301,9 +324,10 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         }
     }
 
+    @Override
     public void logout(OXConnectionInformation info) {
-        if (_journal.isDebugEnabled())
-            _journal.debug("Logging out " + info);
+        if (LOG.isDebugEnabled())
+            LOG.debug("Logging out " + info);
         performLogout(info);
     }
 
@@ -313,6 +337,7 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         OXConnectionData data = (OXConnectionData) info;
         GetMethod method = new GetMethod(getBaseURL() + "login?action=logout&session=" + urlEncode(data.getSessionID()));
         try {
+            // Request statistics can not be collected here, no request may be associated, USM session may no longer be in memory
             executeMethod(data.getHttpClient(), method);
         } catch (HttpException ignored) {
             // do nothing on failed logout
@@ -323,29 +348,33 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         }
     }
 
+    @Override
     public JSONResult doGet(String path, String action, Session session, Map<String, String> parameters) throws AuthenticationFailedException, OXCommunicationException {
         OXConnectionData data = obtainConnectionData(session);
         String url = getBaseURL() + path;
-        if (_journal.isDebugEnabled())
-            _journal.debug(session + " GET " + url);
+        if (LOG.isDebugEnabled())
+            LOG.debug(session + " GET " + url);
         GetMethod method = new GetMethod(url);
         method.setQueryString(generateQueryParameters(action, data.getSessionID(), parameters));
         return executeMethodAndExtractResult(session, data, method, action, parameters);
     }
 
+    @Override
     public JSONResult doPut(String path, String action, Session session, Map<String, String> parameters, JSONArray array) throws AuthenticationFailedException, OXCommunicationException {
         return doPut(path, action, session, parameters, array.toString());
     }
 
+    @Override
     public JSONResult doPut(String path, String action, Session session, Map<String, String> parameters, JSONObject object) throws AuthenticationFailedException, OXCommunicationException {
         return doPut(path, action, session, parameters, object.toString());
     }
 
+    @Override
     public JSONResult doPut(String path, String action, Session session, Map<String, String> parameters, String str) throws AuthenticationFailedException, OXCommunicationException {
         OXConnectionData data = obtainConnectionData(session);
         String url = getBaseURL() + path;
-        if (_journal.isDebugEnabled()) {
-            _journal.debug(session + " PUT " + url + '\n' + str);
+        if (LOG.isDebugEnabled()) {
+            LOG.debug(session + " PUT " + url + '\n' + str);
         }
         PutMethod method = new PutMethod(url);
         method.setQueryString(generateQueryParameters(action, data.getSessionID(), parameters));
@@ -359,10 +388,12 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         return executeMethodAndExtractResult(session, data, method, action, parameters);
     }
 
+    @Override
     public JSONResult doPut(String path, String action, Session session, Map<String, String> parameters, byte[] bytes) throws AuthenticationFailedException, OXCommunicationException {
         return doPut(path, action, session, parameters, "byte array", new ByteArrayRequestEntity(bytes));
     }
 
+    @Override
     public JSONResult doPut(String path, String action, Session session, Map<String, String> parameters, InputStreamProvider streamProvider) throws AuthenticationFailedException, OXCommunicationException {
         return doPut(path, action, session, parameters, "InputStream", new InputStreamProviderRequestEntity(streamProvider));
     }
@@ -370,30 +401,19 @@ public class OXJSONAccessImpl implements OXJSONAccess {
     private JSONResult doPut(String path, String action, Session session, Map<String, String> parameters, String type, RequestEntity entity) throws AuthenticationFailedException, OXCommunicationException {
         OXConnectionData data = obtainConnectionData(session);
         String url = getBaseURL() + path;
-        if (_journal.isDebugEnabled())
-            _journal.debug(session + " PUT " + url + " with " + type);
+        if (LOG.isDebugEnabled())
+            LOG.debug(session + " PUT " + url + " with " + type);
         PutMethod method = new PutMethod(url);
         method.setQueryString(generateQueryParameters(action, data.getSessionID(), parameters));
         method.setRequestEntity(entity);
         return executeMethodAndExtractResult(session, data, method, action, parameters);
     }
 
-    public void activate(Log log, String oxJSONURL, int maxConnections, int connectionTimeout, boolean performStaleChecking, boolean passHostHeaderFromClient, String reloginErrorCodes) {
-        String error = doActivate(log, oxJSONURL, maxConnections, connectionTimeout, performStaleChecking, passHostHeaderFromClient, reloginErrorCodes);
-        if (error != null) {
-            error = "OXJSONAccess not activated, reason: " + error;
-            log.error(error);
-            deactivate(null);
-            throw new USMStartupException(OXJSONErrorCode.ACCESSIMPL_OXAJAXACCESS_NOTACTIVATED_ENCODING_NUMBER_8, error);
-        }
-    }
-
     public void deactivate() {
         deactivate("USM OXJSONAccess deactivated");
     }
 
-    private String doActivate(Log log, String oxJSONURL, int maxConnections, int connectionTimeout, boolean performStaleChecking, boolean passHostHeaderFromClient, String reloginErrorCodes) {
-        _journal = log;
+    private String doActivate(String oxJSONURL, int maxConnections, int connectionTimeout, boolean performStaleChecking, boolean passHostHeaderFromClient, String reloginErrorCodes) {
         _oxJSONBaseURLasString = oxJSONURL;
         _passClientHostHeader = passHostHeaderFromClient;
         try {
@@ -426,7 +446,7 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         _backgroundConnectionCloser.setPriority(Thread.MIN_PRIORITY);
         _backgroundConnectionCloser.setDaemon(true);
         _backgroundConnectionCloser.start();
-        _journal.info("USM OXJSONAccess activated, OX-URL=" + _oxJSONBaseURLasString);
+        LOG.info("USM OXJSONAccess activated, OX-URL=" + _oxJSONBaseURLasString);
         return null;
     }
 
@@ -443,15 +463,14 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         _oxJSONBaseURL = null;
         _oxJSONBaseURLasString = null;
         if (message != null)
-            _journal.info(message);
-        _journal = null;
+            LOG.info(message);
     }
 
     private OXConnectionData obtainConnectionData(Session session) throws AuthenticationFailedException, OXCommunicationException {
         obtainRequiredLock(session, "<obtain OX connection data>");
         try {
             OXConnectionData o = getCurrentOXConnectionData(session);
-            _journal.debug(session + " Retrieving OX session with ID: " + o);
+            LOG.debug(session + " Retrieving OX session with ID: " + o);
             return (o == null) ? performLogin(session) : o;
         } finally {
             releaseLock(session);
@@ -497,8 +516,8 @@ public class OXJSONAccessImpl implements OXJSONAccess {
             JSONResult result = executeMethodOnce(session, data.getHttpClient(), method);
             // On specific error for expired/unknown session, do login and repeat
             if (OXJSONSupport.shouldPerformNewLogin(result)) {
-                if (_journal.isDebugEnabled())
-                    _journal.debug(session + " Session with sessionid " + data.getSessionID() + " unknown to OX server, performing login and repeat");
+                if (LOG.isDebugEnabled())
+                    LOG.debug(session + " Session with sessionid " + data.getSessionID() + " unknown to OX server, performing login and repeat");
                 login(session);
                 data = obtainConnectionData(session);
                 method.setQueryString(generateQueryParameters(action, data.getSessionID(), parameters));
@@ -506,8 +525,8 @@ public class OXJSONAccessImpl implements OXJSONAccess {
                 result = executeMethodOnce(session, data.getHttpClient(), method);
             }
             for (int i = 0; i < MAX_RETRY && shouldRetryRequest(result); i++) {
-                if (_journal.isDebugEnabled())
-                    _journal.debug("Server returned error from category: " + OXJSONUtil.getJSONErrorCategory(result.getJSONObject()) + ". Retrying request..");
+                if (LOG.isDebugEnabled())
+                    LOG.debug("Server returned error from category: " + OXJSONUtil.getJSONErrorCategory(result.getJSONObject()) + ". Retrying request..");
                 result = executeMethodOnce(session, data.getHttpClient(), method);
             }
             if (shouldRetryRequest(result))
@@ -522,7 +541,7 @@ public class OXJSONAccessImpl implements OXJSONAccess {
     }
 
     private JSONResult executeMethodOnce(Session session, HttpClient client, HttpMethodBase method) throws OXCommunicationException {
-        boolean collectOXStatistics = ALWAYS_COLLECT_STATISTICS || _journal.isDebugEnabled();
+        boolean collectOXStatistics = ALWAYS_COLLECT_STATISTICS || LOG.isDebugEnabled();
         long startTime = collectOXStatistics ? System.currentTimeMillis() : 0L;
         try {
             int statusCode = executeMethod(client, method);
@@ -534,8 +553,8 @@ public class OXJSONAccessImpl implements OXJSONAccess {
                     OXJSONErrorCode.ACCESSIMPL_CONFLICT_CHANGE_ON_OXACCESS_NUMBER_12,
                     "Conflicting change on OX access",
                     result.getJSONObject());
-            if (_journal.isDebugEnabled())
-                _journal.debug("RESULT: " + result);
+            if (LOG.isDebugEnabled())
+                LOG.debug("RESULT: " + result);
             return result;
         } catch (HttpException e) {
             throw new OXCommunicationException(OXJSONErrorCode.ACCESSIMPL_HTTPEXCEPTION_OCCURED_NUMBER_13, e);
@@ -543,16 +562,19 @@ public class OXJSONAccessImpl implements OXJSONAccess {
             throw new OXCommunicationException(OXJSONErrorCode.ACCESSIMPL_EXECUTE_METHOD_ERROR_NUMBER_14, e);
         } finally {
             method.releaseConnection();
-            if (collectOXStatistics) {
-                long duration = System.currentTimeMillis() - startTime;
-                long number = getSessionProperty(session, OXJSONPropertyNames.NUMBER_OF_CALLS);
-                session.setCustomProperty(OXJSONPropertyNames.NUMBER_OF_CALLS, Long.valueOf(number + 1L));
-                long accTime = getSessionProperty(session, OXJSONPropertyNames.ACCUMULATED_TIME);
-                session.setCustomProperty(OXJSONPropertyNames.ACCUMULATED_TIME, Long.valueOf(accTime + duration));
-            }
+            if (collectOXStatistics)
+                collectOXStatistics(session, startTime);
         }
     }
 
+    public static void collectOXStatistics(Session session, long startTime) {
+        long duration = System.currentTimeMillis() - startTime;
+        long number = getSessionProperty(session, OXJSONPropertyNames.NUMBER_OF_CALLS);
+        session.setCustomProperty(OXJSONPropertyNames.NUMBER_OF_CALLS, Long.valueOf(number + 1L));
+        long accTime = getSessionProperty(session, OXJSONPropertyNames.ACCUMULATED_TIME);
+        session.setCustomProperty(OXJSONPropertyNames.ACCUMULATED_TIME, Long.valueOf(accTime + duration));
+    }
+    
     private static long getSessionProperty(Session session, String name) {
         Object o = session.getCustomProperty(name);
         return (o instanceof Long) ? ((Long) o).longValue() : 0L;
@@ -576,9 +598,11 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         boolean freeMethod = true;
         try {
             String resourceMessage = session + " GET " + _oxJSONBaseURLasString + " + " + path;
-            if (_journal.isDebugEnabled())
-                _journal.debug(resourceMessage);
+            if (LOG.isDebugEnabled())
+                LOG.debug(resourceMessage);
             OXConnectionData connectionData = obtainConnectionData(session);
+            boolean collectOXStatistics = ALWAYS_COLLECT_STATISTICS || LOG.isDebugEnabled();
+            long startTime = collectOXStatistics ? System.currentTimeMillis() : 0L;
             if (parameters == null) {
                 HttpURL url = getURLFromString(path);
                 if (url.isRelativeURI()) {
@@ -607,8 +631,8 @@ public class OXJSONAccessImpl implements OXJSONAccess {
             }
             String contentType = responseHeader.getValue().toLowerCase();
             if (isValidResourceContentType(contentType)) {
+                ResourceInputStreamImpl ris = new ResourceInputStreamImpl(this, session, connectionData, method, contentType, resourceMessage, startTime);
                 freeMethod = false;
-                ResourceInputStreamImpl ris = new ResourceInputStreamImpl(this, session, connectionData, method, contentType, resourceMessage);
                 return ris;
             }
             if (contentType == null || !contentType.startsWith(TEXT_HTML))
@@ -638,10 +662,12 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         }
     }
 
+    @Override
     public OXResource getResource(Session session, String path, Map<String, String> parameters) throws AuthenticationFailedException, OXCommunicationException {
         obtainRequiredLock(session, "GET " + path + ' ' + parameters);
-        ResourceInputStreamImpl data = accessResource(session, path, parameters);
+        ResourceInputStreamImpl data = null;
         try {
+            data = accessResource(session, path, parameters);
             try {
                 return new OXResource(data.getContentType(), extractResponseBody(data.getMethod()));
             } finally {
@@ -649,9 +675,13 @@ public class OXJSONAccessImpl implements OXJSONAccess {
             }
         } catch (IOException e) {
             throw new OXCommunicationException(OXJSONErrorCode.ACCESSIMPL_CAN_NOT_READ_RESOURCE, e);
+        } finally {
+            if(data == null)
+                releaseLock(session);
         }
     }
 
+    @Override
     public ResourceInputStream getResourceAsStream(Session session, String path, Map<String, String> parameters) throws AuthenticationFailedException, OXCommunicationException {
         obtainRequiredLock(session, "(as stream) GET " + path + ' ' + parameters);
         try {
@@ -665,12 +695,23 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         }
     }
 
+    @Override
     public JSONResult storeResource(String path, String action, Session session, Map<String, String> parameters, JSONObject jsonData, byte[] imageByteData, String fileContentType) throws AuthenticationFailedException, OXCommunicationException {
         return storeResource(path, action, session, parameters, jsonData, imageByteData, fileContentType, STRING_PART_NAME, FILE_PART_NAME);
     }
 
     public JSONResult storeResourceFromStream(String path, String action, Session session, Map<String, String> parameters, JSONObject jsonData, String fileContentType, final long size, final InputStreamProvider streamProvider) throws AuthenticationFailedException, OXCommunicationException {
-        return storeResourceFromStream(path, action, session, parameters, jsonData, fileContentType, STRING_PART_NAME, FILE_PART_NAME, size, streamProvider);
+        return storeResourceFromStream(
+            path,
+            action,
+            session,
+            parameters,
+            jsonData,
+            fileContentType,
+            STRING_PART_NAME,
+            FILE_PART_NAME,
+            size,
+            streamProvider);
     }
 
     public JSONResult storeResource(String path, String action, Session session, Map<String, String> parameters, JSONObject jsonData, byte[] imageByteData, String fileContentType, String jsonPartName, String filePartName) throws AuthenticationFailedException, OXCommunicationException {
@@ -678,17 +719,21 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         return storeResource(path, action, session, parameters, jsonData, fileContentType, jsonPartName, filePartName, source);
     }
 
+    @Override
     public JSONResult storeResourceFromStream(String path, String action, Session session, Map<String, String> parameters, JSONObject jsonData, String fileContentType, String jsonPartName, final String filePartName, final long size, final InputStreamProvider streamProvider) throws AuthenticationFailedException, OXCommunicationException {
         PartSource source = new PartSource() {
 
+            @Override
             public long getLength() {
                 return size;
             }
 
+            @Override
             public String getFileName() {
                 return filePartName;
             }
 
+            @Override
             public InputStream createInputStream() throws IOException {
                 return streamProvider.getInputStream();
             }
@@ -698,12 +743,14 @@ public class OXJSONAccessImpl implements OXJSONAccess {
 
     private JSONResult storeResource(String path, String action, Session session, Map<String, String> parameters, JSONObject jsonData, String fileContentType, String jsonPartName, String filePartName, PartSource dataSource) throws AuthenticationFailedException, OXCommunicationException {
         PostMethod multiPartPostMethod = null;
+        boolean collectOXStatistics = ALWAYS_COLLECT_STATISTICS || LOG.isDebugEnabled();
+        long startTime = 0L;
         try {
             OXConnectionData connectionData = obtainConnectionData(session);
             String url = getBaseURL() + path;
 
-            if (_journal.isDebugEnabled())
-                _journal.debug(session + " POST " + url);
+            if (LOG.isDebugEnabled())
+                LOG.debug(session + " POST " + url);
 
             multiPartPostMethod = new PostMethod(url);
             multiPartPostMethod.setQueryString(generateQueryParameters(action, connectionData.getSessionID(), parameters));
@@ -725,6 +772,8 @@ public class OXJSONAccessImpl implements OXJSONAccess {
                 parts.toArray(new Part[parts.size()]),
                 multiPartPostMethod.getParams()));
 
+            if(collectOXStatistics)
+                startTime = System.currentTimeMillis();
             int statusCode = executeMethod(connectionData.getHttpClient(), multiPartPostMethod);
             if (statusCode != HttpStatus.SC_OK)
                 throw new OXCommunicationException(OXJSONErrorCode.ACCESSIMPL_INVALID_STATUSCODE_NUMBER_19, statusCode);
@@ -739,6 +788,8 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         } finally {
             if (multiPartPostMethod != null)
                 multiPartPostMethod.releaseConnection();
+            if(collectOXStatistics && startTime != 0L)
+                collectOXStatistics(session, startTime);
         }
     }
 
@@ -786,10 +837,10 @@ public class OXJSONAccessImpl implements OXJSONAccess {
     }
 
     private int executeMethod(HttpClient client, HttpMethod method) throws HttpException, IOException {
-        if (_journal.isDebugEnabled())
-            _journal.debug(method.getName() + method.getPath() + "&" + method.getQueryString());
+        if (LOG.isDebugEnabled())
+            LOG.debug(method.getName() + method.getPath() + "&" + method.getQueryString());
         for (Header header : method.getRequestHeaders()) {
-            _journal.debug("Header: " + header.getName() + ":" + header.getValue());
+            LOG.debug("Header: " + header.getName() + ":" + header.getValue());
         }
         int status = HttpStatus.SC_NOT_FOUND;
         method.setFollowRedirects(false);
@@ -806,7 +857,7 @@ public class OXJSONAccessImpl implements OXJSONAccess {
             if (location == null) {
                 if (i > 0 && _lastRedirect < System.currentTimeMillis() - REDIRECT_RETEST_INTERVAL) {
                     _lastRedirect = System.currentTimeMillis();
-                    _journal.info("HTTP Access to JSON interface of OX-Server was redirected. Redirect from server: '" + redirectFromServer + "', used URL: '" + method.getURI() + "'");
+                    LOG.info("HTTP Access to JSON interface of OX-Server was redirected. Redirect from server: '" + redirectFromServer + "', used URL: '" + method.getURI() + "'");
                 }
                 return status;
             }
@@ -816,7 +867,7 @@ public class OXJSONAccessImpl implements OXJSONAccess {
                 newURI = new URI(method.getURI(), newURI);
             method.setURI(newURI);
         }
-        _journal.error("Too many HTTP redirects accessing JSON interface of OX-Server");
+        LOG.error("Too many HTTP redirects accessing JSON interface of OX-Server");
         return status;
     }
 
@@ -824,6 +875,7 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         return (status == HttpStatus.SC_MOVED_PERMANENTLY || status == HttpStatus.SC_SEE_OTHER || status == HttpStatus.SC_TEMPORARY_REDIRECT) ? method.getResponseHeader("location") : null;
     }
 
+    @Override
     public JSONResult doPost(String path, String action, Session session, Map<String, String> parameters) throws AuthenticationFailedException, OXCommunicationException {
 
         OXConnectionData data = obtainConnectionData(session);
@@ -881,7 +933,7 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         if (data != null) {
             ResourceInputStreamImpl currentRIS = data.getCurrentResourceInputStream();
             if (currentRIS != null && currentRIS.getLastActivity() < System.currentTimeMillis() - _STREAM_INACTIVITY_TIMEOUT) {
-                _journal.info("Closing ResourceInputStream due to long inactivity (was locked by " + getRequestInformation(session) + "): " + currentRIS);
+                LOG.info("Closing ResourceInputStream due to long inactivity (was locked by " + getRequestInformation(session) + "): " + currentRIS);
                 try {
                     currentRIS.close();
                 } catch (IOException ignored) {
@@ -921,6 +973,7 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         return (contentType != null) && (APPLICATION_OCTET_STREAM.equals(contentType) || APPLICATION_OCTET_STREAM_UTF_8.equals(contentType) || contentType.startsWith(IMAGE));
     }
 
+    @Override
     public MultiThreadedHttpConnectionManager getHttpConnectionManager() {
         return _httpManager;
     }
