@@ -49,17 +49,18 @@
 
 package com.openexchange.usm.ox_json.impl;
 
+import static com.openexchange.usm.util.OXJSONUtil.DATA_FIELD;
+import static com.openexchange.usm.util.OXJSONUtil.ERROR_FIELD;
+import static com.openexchange.usm.util.OXJSONUtil._RELOGIN_ERROR_CODES;
+import static com.openexchange.usm.util.OXJSONUtil.isOXError;
 import java.io.IOException;
-import java.util.HashSet;
-import java.util.Set;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
 import org.json.JSONTokener;
-import com.openexchange.usm.ox_json.JSONResult;
-import com.openexchange.usm.ox_json.JSONResultType;
+import com.openexchange.usm.api.ox.json.JSONResult;
+import com.openexchange.usm.api.ox.json.JSONResultType;
 import com.openexchange.usm.util.OXJSONUtil;
-import static com.openexchange.usm.util.OXJSONUtil.*;
 
 public class OXJSONSupport {
 
@@ -81,6 +82,7 @@ public class OXJSONSupport {
                         errorDetails.put(DATA_FIELD, result.getJSONArray());
                         errorDetails.put(ERROR_FIELD, "Invalid array response from server, expected " + expectedResultType);
                     } catch (JSONException ignored) {
+                        //should not happen - object creation
                     }
                     return new JSONErrorResult(errorDetails);
                 }
@@ -95,6 +97,7 @@ public class OXJSONSupport {
                 break;
             }
         } catch (JSONException ignored) {
+            //Should not happen - object creation
         }
         if (isValidResultType(expectedResultType, JSONResultType.String))
             return new JSONStringResult(content);
@@ -103,6 +106,7 @@ public class OXJSONSupport {
             errorDetails.put(DATA_FIELD, content);
             errorDetails.put(ERROR_FIELD, "Invalid string response from server, expected " + expectedResultType);
         } catch (JSONException ignored) {
+          //Should not happen - object creation
         }
         return new JSONErrorResult(errorDetails);
     }
