@@ -49,54 +49,31 @@
 
 package com.openexchange.groupware.settings.tree.modules.interfaces;
 
-import org.apache.commons.logging.Log;
-import org.osgi.service.component.ComponentContext;
 import com.openexchange.groupware.settings.tree.AbstractModules;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
-import com.openexchange.usm.journal.Journal;
 
 public class USMActive extends AbstractModules {
 
-	/**
-	 * Default constructor.
-	 */
-	public USMActive() {
-		super();
-	}
+    /**
+     * Default constructor.
+     */
+    public USMActive() {
+        super();
+    }
 
-	/**
-	 * {@inheritDoc}
-	 */
-	public String[] getPath() {
-		return new String[] { "modules", "com.openexchange.usm", "active" };
-	}
+    /**
+     * {@inheritDoc}
+     */
+    @Override
+    public String[] getPath() {
+        return new String[] { "modules", "com.openexchange.usm", "active" };
+    }
 
-	/**
-	 * {@inheritDoc}
-	 */
-	@Override
-	protected boolean getModule(final UserConfiguration userConfig) {
-		return userConfig.hasUSM();
-	}
-
-	private Log _journal;
-
-	/*
-	 * (non-Javadoc)
-	 * @see org.osgi.framework.BundleActivator#start(org.osgi.framework.BundleContext)
-	 */
-	public void activate(ComponentContext context) {
-		Journal journal = (Journal) context.locateService(Journal.class.getName());
-		_journal = journal.getLog(USMActive.class);
-		_journal.info("USM active Preferences Item Service activated");
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * @see org.osgi.framework.BundleActivator#stop(org.osgi.framework.BundleContext)
-	 */
-	public void deactivate(ComponentContext context) {
-		_journal.info("USM active Preferences Item Service deactivated");
-		_journal = null;
-	}
+    /**
+     * {@inheritDoc}
+     */
+    @Override
+    protected boolean getModule(final UserConfiguration userConfig) {
+        return userConfig.hasUSM();
+    }
 }
