@@ -170,6 +170,10 @@ public class SessionImpl implements Session {
     private long _startDate = 0L;
 
     private long _endDate = Long.MAX_VALUE;
+    
+    private long _startDateCalendar = 0L;
+
+    private long _endDateCalendar = Long.MAX_VALUE;
 
     private int _mailLimit = 0;
 
@@ -1161,6 +1165,26 @@ public class SessionImpl implements Session {
     public void setStartDate(long date) {
         _startDate = (date < START_DATE_LIMIT) ? START_DATE_LIMIT : date;
     }
+    
+    @Override
+    public long getCalendarEndDate() {
+        return _endDateCalendar;
+    }
+
+    @Override
+    public long getCalendarStartDate() {
+        return _startDateCalendar;
+    }
+
+    @Override
+    public void setCalendarEndDate(long date) {
+        _endDateCalendar = date;
+    }
+
+    @Override
+    public void setCalendarStartDate(long date) {
+        _startDateCalendar = (date < START_DATE_LIMIT) ? START_DATE_LIMIT : date;
+    }
 
     @Override
     public int getMailLimit() {
@@ -1246,7 +1270,7 @@ public class SessionImpl implements Session {
      * @throws USMStorageException
      */
     private String getOXObjectID(UUID uuid, String folderID, ContentType contentType) throws StorageAccessException, USMStorageException {
-        long[] allTimestamps = _syncStateStorage.getSortedTimestamps(folderID);
+        long[] allTimestamps = _syncStateStorage.getSortedTimestamps(getShortFolderID(folderID));
         for (int i = allTimestamps.length - 1; i >= 0; i--) {
             DataObject[] allObjects = getCachedFolderElements(folderID, contentType, allTimestamps[i]);
             for (DataObject dataObject : allObjects) {
