@@ -49,9 +49,6 @@
 
 package com.openexchange.usm.session.impl;
 
-import java.sql.PreparedStatement;
-import java.sql.ResultSet;
-import java.sql.SQLException;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
@@ -63,69 +60,71 @@ import javax.management.NotCompliantMBeanException;
 import javax.management.ObjectName;
 import org.apache.commons.httpclient.MultiThreadedHttpConnectionManager;
 import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import org.json.JSONObject;
+import com.openexchange.annotation.NonNull;
+import com.openexchange.cluster.lock.ClusterLockService;
 import com.openexchange.exception.OXException;
 import com.openexchange.management.ManagementService;
 import com.openexchange.timer.ScheduledTimerTask;
 import com.openexchange.timer.TimerService;
 import com.openexchange.usm.api.USMVersion;
 import com.openexchange.usm.api.cache.SyncStateCacheProvider;
-import com.openexchange.usm.api.contenttypes.ContentType;
-import com.openexchange.usm.api.contenttypes.ContentTypeManager;
-import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
-import com.openexchange.usm.api.contenttypes.FolderContentType;
-import com.openexchange.usm.api.database.DatabaseAccess;
-import com.openexchange.usm.api.database.DatabaseAccessException;
-import com.openexchange.usm.api.database.EncapsulatedConnection;
+import com.openexchange.usm.api.configuration.ConfigurationManager;
+import com.openexchange.usm.api.configuration.ConfigurationProperties;
+import com.openexchange.usm.api.contenttypes.common.ContentType;
+import com.openexchange.usm.api.contenttypes.common.ContentTypeManager;
+import com.openexchange.usm.api.contenttypes.common.DefaultContentTypes;
+import com.openexchange.usm.api.contenttypes.folder.FolderContentType;
+import com.openexchange.usm.api.database.StorageAccessException;
 import com.openexchange.usm.api.exceptions.AuthenticationFailedException;
 import com.openexchange.usm.api.exceptions.OXCommunicationException;
 import com.openexchange.usm.api.exceptions.USMAccessDeniedException;
 import com.openexchange.usm.api.exceptions.USMException;
-import com.openexchange.usm.api.exceptions.USMResourceAccessException;
-import com.openexchange.usm.api.exceptions.USMSQLException;
+import com.openexchange.usm.api.exceptions.USMInvalidConfigurationException;
 import com.openexchange.usm.api.exceptions.USMStartupException;
+import com.openexchange.usm.api.exceptions.USMStorageException;
+import com.openexchange.usm.api.mapping.storage.ContextUUIDMappingStorage;
+import com.openexchange.usm.api.mapping.storage.FolderIDMappingStorage;
+import com.openexchange.usm.api.ox.json.OXJSONAccess;
 import com.openexchange.usm.api.session.DataObject;
 import com.openexchange.usm.api.session.Folder;
 import com.openexchange.usm.api.session.Session;
-import com.openexchange.usm.api.session.SessionID;
 import com.openexchange.usm.api.session.SessionInitializer;
 import com.openexchange.usm.api.session.SessionManager;
-import com.openexchange.usm.api.session.UserID;
-import com.openexchange.usm.configuration.ConfigurationManager;
-import com.openexchange.usm.configuration.ConfigurationProperties;
-import com.openexchange.usm.configuration.USMInvalidConfigurationException;
-import com.openexchange.usm.mapping.ObjectIdMappingService;
-import com.openexchange.usm.ox_event.OXEventListener;
-import com.openexchange.usm.ox_event.OXEventManager;
-import com.openexchange.usm.ox_json.OXJSONAccess;
+import com.openexchange.usm.api.session.assets.SessionID;
+import com.openexchange.usm.api.session.assets.UserID;
+import com.openexchange.usm.api.session.storage.PersistentSessionDataStorage;
+import com.openexchange.usm.api.session.storage.PersistentSyncStateStorage;
+import com.openexchange.usm.session.cache.MemorySyncStateCacheProvider;
 import com.openexchange.usm.session.dataobject.DataObjectSet;
 import com.openexchange.usm.session.dataobject.FolderImpl;
-import com.openexchange.usm.session.impl.cache.MemorySyncStateCacheProvider;
+import com.openexchange.usm.session.jmx.USMCacheInformation;
+import com.openexchange.usm.session.jmx.USMSessionInformation;
+import com.openexchange.usm.session.jmx.USMSessionInformationMBean;
+import com.openexchange.usm.session.storage.SessionStorage;
 import com.openexchange.usm.session.sync.IncrementalContentSyncer;
 import com.openexchange.usm.session.sync.OXDataCache;
 import com.openexchange.usm.session.sync.SlowContentSyncer;
 import com.openexchange.usm.session.sync.SynchronizationLock;
+import com.openexchange.usm.session.tasks.USMSessionCacheCleanupLogInfoTask;
+import com.openexchange.usm.session.tasks.USMSessionCacheCleanupTask;
+import com.openexchange.usm.session.tasks.USMSessionCleanupTask;
 import com.openexchange.usm.util.JSONToolkit;
 import com.openexchange.usm.util.TempFileStorage;
-import com.openexchange.usm.util.Toolkit;
-import com.openexchange.usm.uuid.OXObjectID;
-import com.openexchange.usm.uuid.UUIDMappingService;
-import com.openexchange.usm.uuid.exceptions.OXObjectAlreadyMappedException;
-import com.openexchange.usm.uuid.exceptions.UUIDAlreadyMappedException;
+import com.openexchange.usm.util.UUIDToolkit;
 
-public class SessionManagerImpl implements SessionManager, OXEventListener {
+public class SessionManagerImpl implements SessionManager {
 
     // Stores interval after which an automatic access check is performed.
     // LATER we might want to make this constant configurable
     private final static long ACCESS_CHECK_INTERVAL = 300000L;
 
-    // private final static long SESSION_CACHE_CHECK_INTERVAL = 5000L;
-
     private final static long ONE_HOUR_IN_MILLISECONDS = 24L * 60L * 60L * 1000L;
 
     private final static long ONE_DAY_IN_MILLISECONDS = 24L * ONE_HOUR_IN_MILLISECONDS;
 
-    public static final String LAST_ACCESS_FIELD_NAME = "USM_ACCESS";
+    private static final String LAST_ACCESS_FIELD_NAME = "USM_ACCESS";
 
     private static final long LAST_ACCESS_UPDATE_INTERVAL = 3L * ONE_HOUR_IN_MILLISECONDS;
 
@@ -138,27 +137,23 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
         SPECIAL_FOLDERS.add(DefaultContentTypes.RESOURCES_ID);
     }
 
-    private OXJSONAccess _oxAjaxAccess;
+    private static final Log LOG = LogFactory.getLog(SessionManagerImpl.class);
 
-    private Log _journal;
+    private final OXJSONAccess _oxAjaxAccess;
 
-    private ContentTypeManager _contentTypeManager;
+    private final ContentTypeManager _contentTypeManager;
 
-    private FolderContentType _folderContentType;
+    private final FolderContentType _folderContentType;
 
-    private SessionStorage _sessionStorage;
+    private final SessionStorage _sessionStorage;
 
-    private OXDataCache _dataCache;
+    private final OXDataCache _dataCache;
 
-    private OXEventManager _oxEventManager;
+    private final ConfigurationManager _configurationManager;
 
-    private ConfigurationManager _configurationManager;
+    private final FolderIDMappingStorage _mappingService;
 
-    private DatabaseAccess _databaseAccess;
-
-    private ObjectIdMappingService _mappingService;
-
-    private UUIDMappingService _uuidService;
+    private final ContextUUIDMappingStorage _uuidService;
 
     private ManagementService _managementService;
 
@@ -199,31 +194,56 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
 
     private final SyncStateCacheProvider _defaultCacheProvider = new MemorySyncStateCacheProvider(this);
 
+    private final PersistentSyncStateStorage syncStateStorage;
+
+    private final PersistentSessionDataStorage sessionDataStorage;
+
     private SyncStateCacheProvider _syncStateCacheProvider;
 
-    public SessionManagerImpl() {
-    }
+    private final List<String> _waitEnabledProtocols = new ArrayList<String>(); // List because we only have 1 or 2 enabled protocols
+
+    private ClusterLockService clusterLockService;
 
     /**
      * This constructor is used only for tests of the IncrementalContentSyncer and SlowContentSyncer.
      * 
      * @param log
      */
-    public SessionManagerImpl(Log log) {
-        _journal = log;
+    public SessionManagerImpl() {
         _dataCache = new OXDataCache(0, 0);
+        _oxAjaxAccess = null;
+        _contentTypeManager = null;
+        _configurationManager = null;
+        _folderContentType = null;
+        _sessionStorage = null;
+        _mappingService = null;
+        _uuidService = null;
+        syncStateStorage = null;
+        sessionDataStorage = null;
     }
 
-    public void activate(Log log, OXJSONAccess ajaxAccess, ContentTypeManager contentTypeManager, FolderContentType folderContentType, OXEventManager oxEventManager, ConfigurationManager configurationManager, DatabaseAccess dbAccess, ObjectIdMappingService mappingService, UUIDMappingService uuidService) {
-        _journal = log;
+    /**
+     * Initializes a new {@link SessionManagerImpl}.
+     * 
+     * @param ajaxAccess
+     * @param contentTypeManager
+     * @param folderContentType
+     * @param configurationManager
+     * @param dbAccess
+     * @param mappingService
+     * @param uuidService
+     * @param ssStorage
+     * @param psdStorage
+     */
+    public SessionManagerImpl(OXJSONAccess ajaxAccess, ContentTypeManager contentTypeManager, FolderContentType folderContentType, ConfigurationManager configurationManager, FolderIDMappingStorage folderIdMappingService, ContextUUIDMappingStorage uuidService, PersistentSyncStateStorage ssStorage, PersistentSessionDataStorage psdStorage) {
         _oxAjaxAccess = ajaxAccess;
         _contentTypeManager = contentTypeManager;
         _folderContentType = folderContentType;
-        _oxEventManager = oxEventManager;
         _configurationManager = configurationManager;
-        _databaseAccess = dbAccess;
-        _mappingService = mappingService;
+        _mappingService = folderIdMappingService;
         _uuidService = uuidService;
+        syncStateStorage = ssStorage;
+        sessionDataStorage = psdStorage;
         try {
             _syncRetryCount = _configurationManager.getProperty(
                 ConfigurationProperties.SYNC_CONCURRENT_MODIFICATION_MAX_RETRIES_PROPERTY,
@@ -386,79 +406,51 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
 
         _sessionStorage = new SessionStorage(this);
         _dataCache = new OXDataCache(cacheTimeLimitSyncComplete, cacheTimeLimitSyncIncomplete);
-        _oxEventManager.addEventListener(this);
         setTimerService(_timerService); // Initialize timers if TimerService was already set
 
-        _journal.info("USM SessionManager activated");
-        _journal.info("Open-Xchange USM Version " + USMVersion.VERSION + " (Build " + USMVersion.BUILD_NUMBER + ") successfully started");
+        LOG.info("USM SessionManager activated");
+        LOG.info("Open-Xchange USM Version " + USMVersion.VERSION + " (Build " + USMVersion.BUILD_NUMBER + ") successfully started");
     }
 
-    public UUID getContextUUID(int cid) throws DatabaseAccessException, USMSQLException {
+    public UUID getContextUUID(int cid) throws StorageAccessException, USMStorageException {
         return _uuidService == null ? null : _uuidService.getContextUUID(cid);
     }
 
     public void deactivate() {
         deactivateTimers();
-        _oxEventManager.removeEventListener(this);
         _sessionStorage.shutdown(_oxAjaxAccess);
-        _configurationManager = null;
-        _oxEventManager = null;
-        _dataCache = null;
-        _sessionStorage = null;
-        _contentTypeManager = null;
-        _oxAjaxAccess = null;
-        _databaseAccess = null;
-        _mappingService = null;
         _waitForChangesEmailPullDelay = 0;
         _waitForChangesEmailMinPullDelay = -1;
-        _journal.info("USM SessionManager deactivated");
-        _journal = null;
+        LOG.info("USM SessionManager deactivated");
     }
 
+    @Override
     public Session getSession(String user, String password, String protocol, String device) throws USMException {
         return getSession(user, password, protocol, device, null, "127.0.0.1", new HashMap<String, String>());
     }
 
     /*
-     * Optimized code. Does not iterate over all contexts anymore. Instead, the code first 
-     * looks up in the cache for the USM session. If it's not there then tries to login and 
-     * determine the context id from the retrieved session. Finally it performs a database
-     * check only on the previously determined context id.
+     * Optimized code. Does not iterate over all contexts anymore. Instead, the code first looks up in the cache for the USM session. If
+     * it's not there then tries to login and determine the context id from the retrieved session. Finally it performs a database check only
+     * on the previously determined context id.
      */
     // TODO This method is only called by 1 special handler. We may need to talk to the Outlook-Addin-developer(s) if the special
     // error that is reported if the session is not known to USM is really required. If not, we could remove this code
+    @Override
     public boolean existsSessionInDB(String user, String password, String protocol, String device) throws USMException {
         SessionID id = new SessionID(user, protocol, device);
         SessionImpl session = _sessionStorage.getSession(id);
         if (session != null)
             return session.checkProperDBStorage();
-        
-        // FIXME getSession() already creates the session in the DB if it hasn't existed yet. So existsSessionInDB() will now always return true (and the code following the getSession() will always find the session in the DB)
+
+        // FIXME getSession() already creates the session in the DB if it hasn't existed yet. So existsSessionInDB() will now always return
+        // true (and the code following the getSession() will always find the session in the DB)
         session = (SessionImpl) getSession(user, password, protocol, device);
-        
-        int contextId = session.getContextId();
-        EncapsulatedConnection con = _databaseAccess.getReadOnly(contextId);
-        PreparedStatement statement = null;
-        boolean sessionFound = false;
-        try {
-            statement = con.prepareStatement("select usmSessionId from USMSession where " + PersistentSessionDataSQLStatements.DEVICE_IN_CONTEXT);
-            statement.setInt(1, contextId);
-            statement.setString(2, device);
-            statement.setString(3, protocol);
-            ResultSet result = statement.executeQuery();
-            sessionFound = result.next();
-        } catch (SQLException e) {
-            String errorMessage = " SQL error while retrieving session from DB";
-            throw new USMSQLException(USMSessionManagementErrorCodes.PERSISTENT_SESSION_DB_ERROR_2, errorMessage, e);
-        } finally {
-            Toolkit.close(statement);
-            Toolkit.close(con);
-        }
-        
-        return sessionFound;
+        return sessionDataStorage.sessionExistsForDevice(session);
     }
 
-    public Session getSession(String user, String password, String protocol, String device, SessionInitializer initializer, String clientIP, Map<String, String> xHeaders) throws USMException {
+    @Override
+    public @NonNull Session getSession(String user, String password, String protocol, String device, SessionInitializer initializer, String clientIP, Map<String, String> xHeaders) throws USMException {
         SessionID id = new SessionID(user, protocol, device);
         SessionImpl session = _sessionStorage.getSession(id);
         if (session != null) {
@@ -484,31 +476,36 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
         session.setClientIp(clientIP);
         session.setXRequestHeaders(xHeaders);
         _oxAjaxAccess.login(session);
-        JSONObject configuration = _oxAjaxAccess.getConfiguration(session);
-        checkUSMAccess(session, configuration);
-        session.setLastAccessCheck(System.currentTimeMillis());
-        session.initialize(configuration);
+        try {
+            JSONObject configuration = _oxAjaxAccess.getConfiguration(session);
+            checkUSMAccess(session, configuration);
+            session.setLastAccessCheck(System.currentTimeMillis());
+            session.initialize(configuration);
+        } catch (USMException e) {
+            _oxAjaxAccess.logout(session);
+            throw e;
+        }
         _sessionStorage.storeSession(session);
         _usmCacheInformation.newSessionCreated();
         updateLastUSMAccess(session);
         return session;
     }
 
-    private static void updateLastUSMAccess(SessionImpl session) throws USMSQLException, DatabaseAccessException {
+    private static void updateLastUSMAccess(SessionImpl session) throws USMStorageException, StorageAccessException {
         long now = System.currentTimeMillis();
         String oldStringValue = session.getPersistentField(LAST_ACCESS_FIELD_NAME);
-        if(oldStringValue != null) {
+        if (oldStringValue != null) {
             try {
                 long lastAccess = Long.parseLong(oldStringValue);
-                if(now - lastAccess < LAST_ACCESS_UPDATE_INTERVAL)
+                if (now - lastAccess < LAST_ACCESS_UPDATE_INTERVAL)
                     return; // Last access timestamp is not too old, do nothing
-            } catch(NumberFormatException ignored) {
+            } catch (NumberFormatException ignored) {
                 // ignore any invalid data, and simple fall through and store the current timestamp
             }
         }
         session.setPersistentField(LAST_ACCESS_FIELD_NAME, String.valueOf(now));
     }
-    
+
     private boolean recheckUSMAccess(SessionInitializer initializer, SessionImpl session) throws USMException {
         long now = System.currentTimeMillis();
         if (session.getLastAccessCheck() >= now - ACCESS_CHECK_INTERVAL)
@@ -519,18 +516,20 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
         return session.checkProperDBStorage();
     }
 
-    private void checkUSMAccess(SessionImpl session, JSONObject configuration) throws USMAccessDeniedException, AuthenticationFailedException, OXCommunicationException {
+    private void checkUSMAccess(SessionImpl session, JSONObject configuration) throws USMAccessDeniedException, AuthenticationFailedException {
         if (_usmInterface == null || _usmInterface.length() == 0) {
             JSONObject usmModule = getUSMModule(session, configuration, "com.openexchange.usm");
             if (usmModule != null && usmModule.optBoolean("active"))
-              return;
+                return;
         } else {
             JSONObject oxInterfaces = getUSMModule(session, configuration, "interfaces");
             if (oxInterfaces != null && oxInterfaces.optBoolean(_usmInterface))
                 return;
         }
         _oxAjaxAccess.logout(session);
-        throw new USMAccessDeniedException(USMSessionManagementErrorCodes.USM_ACCESS_DISABLED, "USM access disabled for user " + session.getUserIdentifier() + '/' + session.getUser() + " in context " + session.getContextId());
+        throw new USMAccessDeniedException(
+            USMSessionManagementErrorCodes.USM_ACCESS_DISABLED,
+            "USM access disabled for user " + session.getUserIdentifier() + '/' + session.getUser() + " in context " + session.getContextId());
     }
 
     private JSONObject getUSMModule(SessionImpl session, JSONObject configuration, String module) throws AuthenticationFailedException {
@@ -548,7 +547,7 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
     }
 
     public Log getJournal() {
-        return _journal;
+        return LOG;
     }
 
     public ContentTypeManager getContentTypeManager() {
@@ -559,12 +558,12 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
         return _folderContentType;
     }
 
-    public DatabaseAccess getDatabaseAccess() {
-        return _databaseAccess;
+    public FolderIDMappingStorage getMappingService() {
+        return _mappingService;
     }
 
-    public ObjectIdMappingService getMappingService() {
-        return _mappingService;
+    public ContextUUIDMappingStorage getUUIDService() {
+        return _uuidService;
     }
 
     public int getMaxSyncStatesInDB() {
@@ -573,6 +572,7 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
 
     // --- Interface OXEventListener ---
 
+    @Override
     public void folderChanged(int contextId, int userId, String folderId, long timestamp) {
         SessionID[] sessions = _sessionStorage.getActiveSessions(new UserID(contextId, userId));
         if (sessions != null) {
@@ -586,6 +586,7 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
         }
     }
 
+    @Override
     public void folderContentChanged(int contextId, int userId, String folderId, long timestamp) {
         SessionID[] sessions = _sessionStorage.getActiveSessions(new UserID(contextId, userId));
         if (sessions != null) {
@@ -656,44 +657,12 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
         }
     }
 
-    public void storeUUID(DataObject o) throws DatabaseAccessException, USMSQLException, UUIDAlreadyMappedException, OXObjectAlreadyMappedException {
-        int contentTypeCode = o.getContentType().getCode();
-        if (contentTypeCode != DefaultContentTypes.MAIL_CODE) {
-            try {
-                int objectId = Integer.parseInt(o.getID());
-                int folderOwner = o.getParentFolderOwnerID();
-                if (folderOwner == o.getSession().getUserIdentifier())
-                    folderOwner = 0;
-                if (_uuidService != null) {
-                    _uuidService.storeMapping(getModifedUUID(o.getUUID(), folderOwner), new OXObjectID(
-                        o.getSession().getContextId(),
-                        contentTypeCode,
-                        objectId));
-                }
-            } catch (NumberFormatException ignored) {
-                // For all cases in which we have no integer OX object id (e.g. mail folders), only store UUIDs locally in sync states
-            }
-        }
-    }
-
-    public void storeUUID(int cid, ContentType contentType, int objectId, UUID uuid, int folderOwner) throws DatabaseAccessException, USMSQLException, UUIDAlreadyMappedException, OXObjectAlreadyMappedException {
-        OXObjectID oxObjectId = new OXObjectID(cid, contentType.getCode(), objectId);
-        if(_uuidService != null)
-            _uuidService.storeMapping(getModifedUUID(uuid, folderOwner), oxObjectId);
-    }
-
-    // public void storeOrRemapUUID(int cid, ContentType contentType, int objectId, UUID uuid)
-    // throws DatabaseAccessException, USMSQLException, UUIDAlreadyMappedException, OXObjectAlreadyMappedException {
-    // OXObjectID oxObjectId = new OXObjectID(cid, contentType.getCode(), objectId);
-    // _uuidService.storeMapping(uuid, oxObjectId); //TODO: implement method in the uuid service
-    // }
-
-    public DataObjectSet insertStoredUUID(DataObject o, DataObjectSet oldData, DataObjectSet newestCachedData) throws DatabaseAccessException, USMSQLException {
+    public DataObjectSet insertStoredUUID(DataObject o, DataObjectSet oldData, DataObjectSet newestCachedData) throws StorageAccessException, USMStorageException {
         boolean useModifiedUUID = o.getSession().getUserIdentifier() != o.getParentFolderOwnerID();
         if (oldData != null) {
             DataObject oldObject = oldData.get(o.getID());
             if (oldObject != null) {
-                o.setUUID(useModifiedUUID ? getModifedUUID(oldObject.getUUID(), o.getParentFolderOwnerID()) : oldObject.getUUID());
+                o.setUUID(useModifiedUUID ? UUIDToolkit.getModifedUUID(oldObject.getUUID(), o.getParentFolderOwnerID()) : oldObject.getUUID());
                 return newestCachedData;
             }
         }
@@ -708,64 +677,31 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
             break;
         case DefaultContentTypes.MAIL_CODE:
             if (newestCachedData == null)
-                // TODO Optimize so that newest cached data is only retrieved if old data is not already newest cached data ?
                 newestCachedData = new DataObjectSet(o.getSession().getCachedFolderElements(o.getParentFolderID(), o.getContentType()));
             DataObject cachedMail = newestCachedData.get(o.getID());
             if (cachedMail != null)
-                o.setUUID(useModifiedUUID ? getModifedUUID(cachedMail.getUUID(), o.getParentFolderOwnerID()) : cachedMail.getUUID());
+                o.setUUID(useModifiedUUID ? UUIDToolkit.getModifedUUID(cachedMail.getUUID(), o.getParentFolderOwnerID()) : cachedMail.getUUID());
             break;
         default:
-            try {
-                int objectId = Integer.parseInt(o.getID());
-                if (_uuidService != null) {
-                    UUID uuid = _uuidService.getUUID(o.getSession().getContextId(), contentTypeCode, objectId);
-                    o.setUUID(useModifiedUUID ? getModifedUUID(uuid, o.getParentFolderOwnerID()) : uuid);
-                }
-            } catch (NumberFormatException ignored) {
-            }
+            if (newestCachedData == null)
+                newestCachedData = new DataObjectSet(o.getSession().getCachedFolderElements(o.getParentFolderID(), o.getContentType()));
+            DataObject cachedObject = newestCachedData.get(o.getID());
+            UUID uuid = (cachedObject == null) ? null : cachedObject.getUUID();
+            if (uuid == null)
+                uuid = o.getSession().getUUID(o.getContentType(), o.getID());
+            o.setUUID(useModifiedUUID ? UUIDToolkit.getModifedUUID(uuid, o.getParentFolderOwnerID()) : uuid);
             break;
         }
         return newestCachedData;
     }
 
-    public UUID getUUID(Session session, int contentTypeCode, int objectId) throws DatabaseAccessException, USMSQLException {
-        return _uuidService.getUUID(session.getContextId(), contentTypeCode, objectId);
-    }
-
-    public int getMappedObject(Session session, int contentTypeCode, UUID uuid) throws DatabaseAccessException, USMSQLException {
-        OXObjectID oxObjectId = _uuidService.getMappedObject(session.getContextId(), uuid);
-        if (oxObjectId != null && oxObjectId.getContentType() == contentTypeCode)
-            return oxObjectId.getObjectId();
-        else
-            return 0;
-    }
-
-    public void objectDeleted(int contextID, int objectID, int contentType) {
-        OXObjectID oxObjectId = new OXObjectID(contextID, contentType, objectID);
-        try {
-            _uuidService.removeMapping(contextID, oxObjectId);
-        } catch (DatabaseAccessException e) {
-            _journal.error("Database could not be accessed to delete UUID mapping for " + oxObjectId);
-            throw new USMResourceAccessException(
-                USMSessionManagementErrorCodes.OX_EVENT_DB_ERROR_3,
-                "Database could not be accessed to delete UUID mapping for " + oxObjectId,
-                e);
-        } catch (USMSQLException e) {
-            _journal.error("SQL error occurred while deleting UUID mapping for " + oxObjectId);
-            throw new USMResourceAccessException(
-                USMSessionManagementErrorCodes.OX_EVENT_DB_ERROR_4,
-                "SQL error occurred while deleting UUID mapping for " + oxObjectId,
-                e);
-        }
-    }
-
     public synchronized void setManagementService(ManagementService managementService) {
         if (_managementService != null) {
             if (_jmxSessionObjectName != null) {
                 try {
                     _managementService.unregisterMBean(_jmxSessionObjectName);
                 } catch (final OXException e) {
-                    _journal.error(e.getMessage(), e);
+                    LOG.error(e.getMessage(), e);
                 } finally {
                     _jmxSessionObjectName = null;
                     _managementService = null;
@@ -778,11 +714,11 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
                 _jmxSessionObjectName = getObjectName(USMSessionInformation.class.getName(), USMSessionInformationMBean.SESSION_DOMAIN);
                 _managementService.registerMBean(_jmxSessionObjectName, new USMSessionInformation(this, _usmCacheInformation));
             } catch (final MalformedObjectNameException e) {
-                _journal.error(e.getMessage(), e);
+                LOG.error(e.getMessage(), e);
             } catch (final OXException e) {
-                _journal.error(e.getMessage(), e);
+                LOG.error(e.getMessage(), e);
             } catch (NotCompliantMBeanException e) {
-                _journal.error(e.getMessage(), e);
+                LOG.error(e.getMessage(), e);
             }
         }
     }
@@ -841,6 +777,10 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
             _sessionCacheCleanupTask.cancel();
             _sessionCacheCleanupTask = null;
         }
+        if (_sessionCacheCleanupLogInfoTask != null) {
+            _sessionCacheCleanupLogInfoTask.cancel();
+            _sessionCacheCleanupLogInfoTask = null;
+        }
     }
 
     public void setTimerService(TimerService timerService) {
@@ -868,7 +808,7 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
                     true);
 
             } catch (USMInvalidConfigurationException e) {
-                _journal.error(e.getStackTrace(), e);
+                LOG.error(e.getStackTrace(), e);
             }
             _sessionCacheCleanupTask = _timerService.scheduleAtFixedRate(
                 new USMSessionCacheCleanupTask(this),
@@ -886,21 +826,6 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
         return _sessionStorageTimeLimit;
     }
 
-    /**
-     * Creates a modified UUID from a base UUID and a given OX user id. The algorithm uses XOR, so this method can be used both ways, i.e.
-     * given a modified UUID and OX user id, it reports back the original unmodified UUID. If either the UUID is null or the userID is 0,
-     * this method returns the unmodified UUID.
-     * 
-     * @param uuid
-     * @param userID
-     * @return
-     */
-    public UUID getModifedUUID(UUID uuid, int userID) {
-        if (uuid == null || userID == 0)
-            return uuid;
-        return new UUID(uuid.getMostSignificantBits() ^ userID, uuid.getLeastSignificantBits());
-    }
-
     public OXDataCache getOXDataCache() {
         return _dataCache;
     }
@@ -984,4 +909,50 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
         SyncStateCacheProvider provider = _syncStateCacheProvider;
         return (provider == null) ? _defaultCacheProvider : provider;
     }
+
+    public PersistentSyncStateStorage getSyncStateStorage() {
+        return syncStateStorage;
+    }
+
+    public PersistentSessionDataStorage getSessionDataStorage() {
+        return sessionDataStorage;
+    }
+
+    @Override
+    public void objectDeleted(int contextID, int objectID, int contentType) {
+        // nothing to do with new UUID storage mechanism
+    }
+
+    @Override
+    public void enableWaitingForChanges(String protocol) {
+        if (!_waitEnabledProtocols.contains(protocol))
+            _waitEnabledProtocols.add(protocol);
+    }
+
+    @Override
+    public void disableWaitForChanges(String protocol) {
+        _waitEnabledProtocols.remove(protocol);
+        for (SessionImpl session : _sessionStorage.getSessionList()) {
+            if (session.getProtocol().equals(protocol)) {
+                session.notifyOnWaitForChanges();
+            }
+        }
+    }
+
+    public boolean isWaitForChangesEnabled(String protocol) {
+        return _waitEnabledProtocols.contains(protocol);
+    }
+    
+    public void setClusterLockService(ClusterLockService lockService) {
+        clusterLockService = lockService;
+    }
+
+    /**
+     * Gets the clusterLockService
+     *
+     * @return The clusterLockService
+     */
+    public ClusterLockService getClusterLockService() {
+        return clusterLockService;
+    }
 }
