@@ -50,11 +50,13 @@
 package com.openexchange.usm.session.sync;
 
 import java.util.BitSet;
-import com.openexchange.usm.api.contenttypes.ContentType;
-import com.openexchange.usm.api.contenttypes.FolderConstants;
-import com.openexchange.usm.api.contenttypes.FolderContentType;
-import com.openexchange.usm.api.contenttypes.FolderContentTypeTransferHandler;
+import com.openexchange.usm.api.contenttypes.common.ContentType;
+import com.openexchange.usm.api.contenttypes.folder.FolderConstants;
+import com.openexchange.usm.api.contenttypes.folder.FolderContentType;
+import com.openexchange.usm.api.contenttypes.transferhandlers.FolderContentTypeTransferHandler;
+import com.openexchange.usm.api.database.StorageAccessException;
 import com.openexchange.usm.api.exceptions.USMException;
+import com.openexchange.usm.api.exceptions.USMStorageException;
 import com.openexchange.usm.api.session.DataObject;
 import com.openexchange.usm.api.session.DataObjectFilter;
 import com.openexchange.usm.api.session.Folder;
@@ -87,6 +89,7 @@ public class FolderHierarchyStorage implements ContentSyncerStorage {
         _cacheID = session.getFolderHierarchyCacheID();
     }
 
+    @Override
     public boolean getCurrentServerData(DataObjectSet resultSet) throws USMException {
         FolderContentType contentType = _session.getSessionManager().getFolderContentType();
         FolderContentTypeTransferHandler handler = contentType.getTransferHandler();
@@ -115,10 +118,12 @@ public class FolderHierarchyStorage implements ContentSyncerStorage {
         return false;
     }
 
+    @Override
     public long storeServerData(long timestamp, DataObjectSet data, boolean updatesPending) throws USMException {
         return _storeResult ? _session.storeCachedFolders(_oldTimestamp, timestamp, data, updatesPending, _syncStartTimestamp) : 0L;
     }
 
+    @Override
     public OXDataCacheID getCacheID() {
         return _cacheID;
     }
@@ -153,6 +158,7 @@ public class FolderHierarchyStorage implements ContentSyncerStorage {
         f.commitChanges();
     }
 
+    @Override
     public DataObject findMatchingClientObjectForServerObject(DataObjectSet clientDataObjects, DataObject serverObject) {
         if (!_session.getSessionInitializer().objectsSynchronizedByUUID())
             return null;
