@@ -62,8 +62,8 @@ import com.openexchange.exception.OXException;
 import com.openexchange.filemanagement.ManagedFile;
 import com.openexchange.filemanagement.ManagedFileFilter;
 import com.openexchange.filemanagement.ManagedFileManagement;
+import com.openexchange.usm.api.configuration.ConfigurationProperties;
 import com.openexchange.usm.api.session.Session;
-import com.openexchange.usm.configuration.ConfigurationProperties;
 
 /**
  * {@link TempFileStorage} Storage facility that provides session-based access to temp-files (creating, accessing, delete all of a Session)
@@ -80,6 +80,7 @@ public class TempFileStorage {
             _prefix = prefix;
         }
 
+        @Override
         public boolean accept(ManagedFile managedFile) {
             return managedFile.getID().startsWith(_prefix);
         }
@@ -88,7 +89,7 @@ public class TempFileStorage {
     private static final InputStream _EMPTY_INPUT_STREAM = new InputStream() {
 
         @Override
-        public int read() throws IOException {
+        public int read() {
             return -1;
         }
     };
